<?php

namespace Teknisa\DF\Controllers;

use NFePHP\NFe\MakeNFe;
use NFePHP\NFe\ToolsNFe;
use Teknisa\DF\Services\TransmissaoNfeService;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;

class TransmissaoNfeController extends \Teknisa\DF\Controllers\TeknisaCrud
{
    protected $transmissaoNfeService;

    public function __construct(TransmissaoNfeService $transmissaoNfeService)
    {
        $this->transmissaoNfeService = $transmissaoNfeService;
    }

    public function montaConfigTransmissao (Request\Filter $request, Response $response) {
        $requestConditions = $request->getFilterCriteria()->getConditions();
        $row = $requestConditions[0]["value"];
        
        $content = $this->transmissaoNfeService->montaConfigTransmissao($row['CDEMPRESA'], $row['CDINSCESTA'], $row['CDFILIAL'], $row['IDENDEMISFIL']);
        
        $response->addDataset(new \Zeedhi\Framework\DataSource\DataSet('config_transmissao', array('config' => $content)));
    }

    public function statusServico (Request\Filter $request, Response $response){
        $requestConditions = $request->getFilterCriteria()->getConditions();
        $notasfiscais = $requestConditions[0]["value"];
        $config = $requestConditions[1]["value"];

        $statusServico = $this->transmissaoNfeService->statusServico($notasfiscais, $config);

        $response->addDataset(new \Zeedhi\Framework\DataSource\DataSet('statusServico', $statusServico));
    }

    public function transmiteNotas (Request\Filter $request, Response $response){
        $requestConditions = $request->getFilterCriteria()->getConditions();
        $notasfiscais = $requestConditions[0]["value"];
        $config = $requestConditions[1]["value"];
        $tipo = $requestConditions[2]["value"];

        $transmissao = $this->transmissaoNfeService->transmitirNotas($notasfiscais, $config, $tipo);

        $response->addDataset(new \Zeedhi\Framework\DataSource\DataSet('transmiteNotas', $transmissao));
    }

    public function atualizaLote (Request\Filter $request, Response $response){
        $requestConditions = $request->getFilterCriteria()->getConditions();
        $lotesMarcados = $requestConditions[0]["value"];
        $config = $requestConditions[1]["value"];

        $atualizaLote = $this->transmissaoNfeService->atualizaLote($lotesMarcados, $config);

        $response->addDataset(new \Zeedhi\Framework\DataSource\DataSet('atualizaLote', $atualizaLote));
    }

    public function cancelarTransmissao (Request\Filter $request, Response $response){
        $requestConditions = $request->getFilterCriteria()->getConditions();
        $row = $requestConditions[0]["value"];
        $config = $requestConditions[1]["value"];

        $cancelar = $this->transmissaoNfeService->cancelarTransmissao($row, $config);

        $response->addDataset(new \Zeedhi\Framework\DataSource\DataSet('cancelarTransmissao', $cancelar));
    }

    public function enviarCartaCorrecao (Request\Filter $request, Response $response){
        $requestConditions = $request->getFilterCriteria()->getConditions();
        $notafiscal = $requestConditions[0]["value"];
        $dscorrecaonfe = $requestConditions[1]["value"];
        $nrseqcce = $requestConditions[2]["value"];
        $config = $requestConditions[3]["value"];

        try {
            $cartaCorrecao = $this->transmissaoNfeService->enviarCartaCorrecao($notafiscal, $dscorrecaonfe, $nrseqcce, $config);

            $response->addDataset(new \Zeedhi\Framework\DataSource\DataSet('enviarCartaCorrecao', $cartaCorrecao));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function visualizarDanfe (Request\Filter $request, Response $response){
        $requestConditions = $request->getFilterCriteria()->getConditions();
        $nota = $requestConditions[0]["value"];
        $config = $requestConditions[1]["value"];

        try {
            $visualizarDanfe = $this->transmissaoNfeService->visualizarDanfe($nota, $config);
            $response->addDataset(new \Zeedhi\Framework\DataSource\DataSet('visualizarDanfe', $visualizarDanfe));
        } catch (\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_ERROR));

        }
    }

    public function downloadDanfe (Request\Filter $request, Response $response){
        $requestConditions = $request->getFilterCriteria()->getConditions();
        $notasMarcadas = $requestConditions[0]["value"];
        $config = $requestConditions[1]["value"];

        try {
            $downloadDanfe = $this->transmissaoNfeService->downloadDanfe($notasMarcadas, $config);
            $response->addDataset(new \Zeedhi\Framework\DataSource\DataSet('downloadDanfe', array($downloadDanfe)));
        } catch (\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_ERROR));
        }
    }

    public function downloadXML (Request\Filter $request, Response $response){
        $requestConditions = $request->getFilterCriteria()->getConditions();
        $nota = $requestConditions[0]["value"];
        $config = $requestConditions[1]["value"];

        try {
            $downloadXML = $this->transmissaoNfeService->downloadXML($nota, $config);
            $response->addDataset(new \Zeedhi\Framework\DataSource\DataSet('downloadXML', array($downloadXML)));
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function enviarEmailNF (Request\Filter $request, Response $response){
        $requestConditions = $request->getFilterCriteria()->getConditions();
        $nota = $requestConditions[0]["value"];
        $config = $requestConditions[1]["value"];
        $tipo = $requestConditions[2]["value"];

        $enviarEmailNF = $this->transmissaoNfeService->enviarEmailNF($nota, $config, $tipo);

        $response->addDataset(new \Zeedhi\Framework\DataSource\DataSet('enviarEmailNF', $enviarEmailNF));
    }
    
    public function enviarEmailCC(Request\Filter $request, Response $response){
        $requestConditions = $request->getFilterCriteria()->getConditions();
        $nota = $requestConditions[0]["value"];
        $tipo = $requestConditions[1]["value"];
        $nrseqcce = $requestConditions[2]["value"];
        $config = $requestConditions[3]["value"];


        $enviarEmailCC = $this->transmissaoNfeService->enviarEmailCC($nota, $tipo, $nrseqcce, $config);

        $response->addDataset(new \Zeedhi\Framework\DataSource\DataSet('enviarEmailCC', $enviarEmailCC));
    }

    public function maxNrseqcce(Request\Filter $request, Response $response){
        $requestConditions = $request->getFilterCriteria()->getConditions();
        $filial = $requestConditions[0]["value"];
        $lancamento = $requestConditions[1]["value"];

        $maxNrseqcce = $this->transmissaoNfeService->getMaxNrseqcce($filial, $lancamento);

        $response->addDataset(new \Zeedhi\Framework\DataSource\DataSet('maxNrseqcce', array($maxNrseqcce)));
    }
    
    public function verificaTipoOperFili(Request\Row $request, Response $response){
        $row = $request->getRow();
        $liberado = $this->transmissaoNfeService->verificaTipoOperFili($row["CDTIPOOPER"], $row["CDFILIAL"], $row["IDENTRSAIDOP"]);
        $response->addDataset(new \Zeedhi\Framework\DataSource\DataSet('liberado', array($liberado)));
    }
    
    public function verificaRejeicaoXML(Request\Row $request, Response $response){
        $row = $request->getRow();
        $falhaXML = $this->transmissaoNfeService->verificaRejeicaoXML($row["CDFILIAL"], $row["NRLANCTONF"]);
        $response->addDataset(new \Zeedhi\Framework\DataSource\DataSet('falhaXML', array($falhaXML)));
    }
    public function consultaSituacaoNF(Request\Filter $request, Response $response){
        $requestConditions = $request->getFilterCriteria()->getConditions();
        $nota = $requestConditions[0]["value"];
        $config = $requestConditions[1]["value"];
        
        $consultaNF = $this->transmissaoNfeService->consultaSituacaoNF($nota, $config, true);
        
        $response->addDataset(new \Zeedhi\Framework\DataSource\DataSet('consultaSituacaoNF', $consultaNF));
    }
    public function consultaSituacaoAtualNF(Request\Row $request, Response $response){
        $row = $request->getRow();
        
        $data = array();
        
        $data = $this->transmissaoNfeService->consultaSituacaoAtualNF($row["NRACESSONFE"]);
        
        return $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('consultaSituacaoAtualNfeNF',$data));
    }
    
    public function sincronizaDadosNF(Request\Row $request, Response $response){
        $row = $request->getRow();
        
        $resp = array();
        $resp = $this->transmissaoNfeService->sincronizaDadosNota($row["NRACESSONFE"], false);
        if(!isset($resp['APROVADA'])){
            if(isset($resp['ATUALIZOU'])){
                $lote = $this->transmissaoNfeService->sincronizaLote($row["NRACESSONFE"],true);
            }else if(!isset($resp['REJEICAO'])){
               $lote = $this->transmissaoNfeService->sincronizaLote($row["NRACESSONFE"],false); 
            }
        }
        
        return $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('sincronizaNF',$resp));
    }
    
    public function gerarXmlNfe(Request\DataSet $request, Response $response){
        $notas = $request->getDataSet()->getRows();
        $zipName = $this->transmissaoNfeService->gerarXmlNfe($notas);
        $response->addMessage(new Response\Message($zipName));
    }
    
    public function aprovarNotasTransmissao (Request\Filter $request, Response $response) {
        $requestConditions = $request->getFilterCriteria()->getConditions();
        $notas = $requestConditions[0]["value"];
        
        $aprovarNotasTransmissao = $this->transmissaoNfeService->aprovarNotasTransmissao($notas, $response);
        
        $response->addDataset(new \Zeedhi\Framework\DataSource\DataSet('aprovarNotasTransmissao', $aprovarNotasTransmissao));
    }
    
    public function emailAutomaticoTransmissao (Request\Filter $request, Response $response) {
        $requestConditions = $request->getFilterCriteria()->getConditions();
        $notas = $requestConditions[0]["value"];
        $config = $requestConditions[1]["value"];
        
        $emailAutomaticoTransmissao = $this->transmissaoNfeService->emailAutomaticoTransmissao($notas, $config);
        
        $response->addDataset(new \Zeedhi\Framework\DataSource\DataSet('emailAutomaticoTransmissao', $emailAutomaticoTransmissao));
    }
}