<?php

namespace Teknisa\DF\Modules\Entrada\Controllers;

use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Row;
use Zeedhi\Framework\DataSource\DataSet;

use Teknisa\DF\Modules\Entrada\Services\Dfe64000IntegracaoCFOPComTipoOperService;

class Dfe64000IntegracaoCFOPComTipoOperController extends \Teknisa\DF\Controllers\TeknisaCrud {
    
    protected $dataSourceName = 'integracao_cfopxml_x_tipooperacao';
    protected $IntegracaoCFOPComTipoOperService;
    
    public function __construct($crudService, $parameterBag, Dfe64000IntegracaoCFOPComTipoOperService  $IntegracaoCFOPComTipoOperService) {
        parent::__construct($crudService, $parameterBag);
        $this->IntegracaoCFOPComTipoOperService = $IntegracaoCFOPComTipoOperService;
    }
    
     public function save(DTO\Request $request, DTO\Response $response)  {
         
        try {
            $rows = $request->getRow();
            $cdCFOP = $rows['CDCFOPPADRAO'];
            $cdTipoOper = $rows['CDTIPOOPER'];
            $cdFilial = "";
            
            if ($this->dataSourceName == "integracao_cfopxml_x_tipooperacao_filial") {
                $cdFilial = $rows['CDFILIAL'];
            }
            
            $notaUtilizada = $this->IntegracaoCFOPComTipoOperService->verificaCFOPUtilizado($cdCFOP, $cdFilial, $this->dataSourceName);
            
            if(!empty($notaUtilizada)) {
                return $response->setError(new Error($notaUtilizada, 500));
            }
        
            $this->IntegracaoCFOPComTipoOperService->save($cdCFOP, $cdTipoOper, $cdFilial, $this->dataSourceName);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function saveFilial(DTO\Request $request, DTO\Response $response)  {
        $this->dataSourceName = 'integracao_cfopxml_x_tipooperacao_filial';
        $this->save ($request, $response);
    }
    
    public function delete(DTO\Request $request, DTO\Response $response) {
        try {
            $rows = $request->getRow();
            $cdCFOP = $rows['CDFISCOPER'];
            $cdFilial = "";
            
            if ($this->dataSourceName == "integracao_cfopxml_x_tipooperacao_filial") {
                $cdFilial = $rows['CDFILIAL'];
            }
            
            $this->IntegracaoCFOPComTipoOperService->delete($cdCFOP, $cdFilial, $this->dataSourceName);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function deleteFilial(DTO\Request $request, DTO\Response $response)  {
        $this->dataSourceName = 'integracao_cfopxml_x_tipooperacao_filial';
        $this->delete ($request, $response);
    }
}

