<?php

namespace Teknisa\DF\Modules\Entrada\Factories;

use Doctrine\ORM\EntityManager;

class ImportacaoConsultaNotaFiscalFactory {

    protected $entityManager;
    protected $organizacao;
	protected $fileUploader;
	protected $environment;

    public function __construct(EntityManager $entityManager, $environment, $fileUploader) {
    	$this->environment   = $environment;
        $this->entityManager = $entityManager;
        $this->organizacao   = $environment->getNrOrg();
        $this->fileUploader  = $fileUploader;        
        set_time_limit( 0 ); // Limite de tempo de execução: 2h. Deixe 0 (zero) para sem limite
        ignore_user_abort( true );
    }

    public function atualizaNrAutoforn($nrAutoForn, $nrAcessoNFe) {
        $sql = "UPDATE INTG_ITEMPRODUTO
                   SET NRAUTOFORN  = :P_NUMEROAF,
                       DTULTATU    = :DTULTATU,
					   NRORGULTATU  = :NRORGULTATU,
					   CDOPERULTATU = :CDOPERULTATU
                WHERE NRACESSONFE = :P_NRACESSONFE";
                
        $params = array("P_NUMEROAF"    => $nrAutoForn,
                        "P_NRACESSONFE" => $nrAcessoNFe);
		
		$params = $this->adicionaCampos($params, false);
		
        $std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);
    }
    
    public function atualizaNrAutofornProd($nrAutoForn, $nrAcessoNFe, $nrSeqItProd) {
        $sql = "UPDATE INTG_ITEMPRODUTO
                   SET NRAUTOFORN  = :P_NUMEROAF,
                       DTULTATU    = :DTULTATU,
					   NRORGULTATU  = :NRORGULTATU,
					   CDOPERULTATU = :CDOPERULTATU
                WHERE  NRACESSONFE = :P_NRACESSONFE
                   AND NRSEQITPROD = :P_NRSEQITPROD";
                
        $params = array("P_NUMEROAF"    => $nrAutoForn,
                        "P_NRACESSONFE" => $nrAcessoNFe,
                        "P_NRSEQITPROD" => $nrSeqItProd);
                        
        
		$params = $this->adicionaCampos($params, false);
		

        $std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);
    }
    
    public function getFilial($nrinsjurnfili, $cdempresa) {
    	$sql = "select * 
    			from filial f, empresa e 
    			where f.nrinsjurfili = (REPLACE(REPLACE(REPLACE(:P_NRINSJUR, '.', ''), '/', ''), '-', '')) and 
    				  e.cdempresa = :P_CDEMPRESA and 
    	              f.cdempresa = e.cdempresa and
    	              f.nrinsjurfili = e.nrinsjurempr";
    	$params = array("P_NRINSJUR" => $nrinsjurnfili,
    					"P_CDEMPRESA" => $cdempresa);
    	$query =  $this->entityManager->getConnection()->prepare($sql);
    	$query->execute($params);
        return $query->fetchAll();

    }
    
    public function getParamGeral() {
        $sql = "SELECT * FROM PARAMGERAL";

        $query =  $this->entityManager->getConnection()->prepare($sql);
        $query->execute();
        return $query->fetchAll();
    }

	public function getInscEstadual($cdfilial){
		$sql = "SELECT CDINSCESTA FROM EMPRCNTRFIL WHERE CDFILIAL IN (";
		        foreach($cdfilial as $filial) {
		            $sql.="'".$filial."'".',';
		        }
        $size = strlen($sql);
		$sql = substr($sql,0, $size-1).')';
		
		
		$query =  $this->entityManager->getConnection()->prepare($sql);
        $query->execute();
        return $query->fetchAll();
	}
    
    public function verificaNotaGerada($nrAcessoNFe) {
        $sql = "SELECT NVL(IDSTATUSNFE, 'N') AS IDSTATUSNFE, NVL(IDSTATUS, 'N') AS IDSTATUS
                FROM INTG_NOTAFISCAL
            	WHERE NRACESSONFE  = :P_NRACESSONFE";
               
        $params = array("P_NRACESSONFE" => $nrAcessoNFe);

        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getPainelInconsistencias($nrAcessoNFe) {
        $sql = "SELECT T.DSPAINEL,
                  COUNT(T.CDPAINEL) AS TOTAL,
                  T.NRACESSONFE,
                  T.CDPAINEL
                FROM
                  (SELECT P.DSPAINEL,
                    II.NRACESSONFE,
                    P.CDPAINEL
                  FROM CONSISTXML C,
                    ITPANCONSXML I,
                    PAINELCONSXML P,
                    INTG_INCONSISTENCIA II
                  WHERE I.CDCONSISTXML = C.CDCONSISTXML
                  AND I.CDPAINEL       = P.CDPAINEL
                  AND II.CDCONSISTXML  = I.CDCONSISTXML
                  AND II.NRACESSONFE   = :P_NRACESSONFE
                  UNION
                  SELECT 'Erros e Avisos' AS DSPAINEL,
                    I.NRACESSONFE,
                    '00000' AS CDPAINEL
                  FROM INTG_INCONSISTENCIA I
                  WHERE I.NRACESSONFE     = :P_NRACESSONFE
                  AND I.CDCONSISTXML NOT IN
                    (SELECT CDCONSISTXML
                    FROM ITPANCONSXML C
                    WHERE C.CDCONSISTXML = I.CDCONSISTXML
                    )
                  ) T
                GROUP BY T.DSPAINEL,
                  T.NRACESSONFE,
                  T.CDPAINEL";
             
        $params = array("P_NRACESSONFE" => $nrAcessoNFe);
             
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();     
    }
    
    public function getItensInconsistencias($nrAcessoNFe, $cdPainel) {
        $sql =  "SELECT T.DSINCONSIS
                  FROM(SELECT II.DSINCONSIS
                         FROM CONSISTXML C,    ITPANCONSXML I,
                              PAINELCONSXML P, INTG_INCONSISTENCIA II
                        WHERE I.CDCONSISTXML  = C.CDCONSISTXML
                          AND I.CDPAINEL      = P.CDPAINEL
                          AND II.CDCONSISTXML = I.CDCONSISTXML(+)
                          AND II.NRACESSONFE  = :P_NRACESSONFE
                          AND P.CDPAINEL      = :P_CDPAINEL
                        UNION
                       SELECT I.DSINCONSIS
                         FROM INTG_INCONSISTENCIA I
                        WHERE I.NRACESSONFE  = :P_NRACESSONFE
                          AND I.CDCONSISTXML NOT IN (SELECT CDCONSISTXML
                                                       FROM ITPANCONSXML C
                                                      WHERE C.CDCONSISTXML = I.CDCONSISTXML)) T
                ORDER BY T.DSINCONSIS";
                
        $params = array("P_NRACESSONFE" => $nrAcessoNFe,
                        "P_CDPAINEL"    => $cdPainel);
             
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();  
    }
    
    public function getDiretorio() {
        $sql = "SELECT DSDIRIMPARQXML FROM PARAMINTEGRA";
             
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute();
        return $std->fetchAll();
    }
    
	public function getXml($params) {
      $sql = "SELECT IDTIPOARQXML, DSARQXMLNFE_CLOB
        		FROM INTG_ARQXMLNFE 
        		WHERE NRACESSONFE = :P_NRACESSONFE AND NRORG = : P_NRORG";
             
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();  
    }

	public function getImpostos() {
        $sql = "SELECT CDIMPOSTO,
                  SGIMPOSTONFE
                FROM IMPOSTO I,
                  IMPOSTONFE IM
                WHERE I.CDIMPOSTOXML = IM.CDIMPOSTONFE
                AND IM.SGIMPOSTONFE IN ('ICMS','IPI','ISSQN-E','PIS','COFINS', 'II', 'ICMS ST', 'PIS ST', 'COFINS ST')";
                
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute();
        return $std->fetchAll();          
    }

    public function getEncargos() {
        $sql = "SELECT MIN(CDENCARGO) CDENCARGO,
                  MIN(NMENCARGONFE) NMENCARGONFE
                FROM ENCARGO E,
                  ENCARGONFE EN
                WHERE E.CDENCARGONFE = EN.CDENCARGONFE
                AND EN.NMENCARGONFE  = 'Frete'
                UNION ALL
                SELECT MIN(CDENCARGO) CDENCARGO,
                  MIN(NMENCARGONFE) NMENCARGONFE
                FROM ENCARGO E,
                  ENCARGONFE EN
                WHERE E.CDENCARGONFE = EN.CDENCARGONFE
                AND EN.NMENCARGONFE  = 'Seguro'
                UNION ALL
                SELECT MIN(CDENCARGO) CDENCARGO,
                  MIN(NMENCARGONFE) NMENCARGONFE
                FROM ENCARGO E,
                  ENCARGONFE EN
                WHERE E.CDENCARGONFE = EN.CDENCARGONFE
                AND EN.NMENCARGONFE  = 'Descontos'
                UNION ALL
                SELECT MIN(CDENCARGO) CDENCARGO,
                  MIN(NMENCARGONFE) NMENCARGONFE
                FROM ENCARGO E,
                  ENCARGONFE EN
                WHERE E.CDENCARGONFE = EN.CDENCARGONFE
                AND EN.NMENCARGONFE  = 'Outras Despesas'";
                
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute();
        return $std->fetchAll();       
    }
    
    public function getParamIntegracao() {
        $sql = "SELECT NVL(MAX(NRFILPOSINIXML),0) AS NRFILPOSINIXML,
                  NVL(MAX(NRFILPOSFINXML),0)      AS NRFILPOSFINXML,
                  NVL(MAX(NRPROPOSFINXML),0)      AS NRPROPOSFINXML,
                  NVL(MAX(NRPROPOSINIXML),0)      AS NRPROPOSINIXML,
                  NVL(MAX(IDIMPORTXMLNFE), 'N')   AS IDIMPORTXMLNFE
                FROM PARAMINTEGRA";
        
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute();
        return $std->fetchAll(); 
    }
    
    public function insereLogNota($nrAcessoNFe, $dsIncons, $nmArqNf, $nrNotaNf = null, $cdSerieNfe = null, $cdFornNfe = null, $nmFornNfe = null) {
        $sql = "INSERT
            INTO LOGINCONSXML
              (
                NRACESSONFELOG,
                DSINCONSNFELOG,
                NMARQNFELOG,
                NRNOTANFELOG,
                CDSERIENFELOG,
                CDFORNNFELOG,
                NMFORNNFELOG,
                DTINCLUSAO,
				CDOPERINCLUSAO,
				NRORGINCLUSAO,
				IDATIVO,
				DTULTATU,
				NRORGULTATU,
				CDOPERULTATU,
                NRORG
              )
              VALUES
              (
                :P_NRACESSONFELOG,
                :P_DSINCONSNFELOG,
                :P_NMARQNFELOG,
                :P_NRNOTANFELOG,
                :P_CDSERIENFELOG,
                :P_CDFORNNFELOG,
                :P_NMFORNNFELOG,
                :DTINCLUSAO,
				:CDOPERINCLUSAO,
				:NRORGINCLUSAO,
				:IDATIVO,
				:DTULTATU,
				:NRORGULTATU,
				:CDOPERULTATU,
                :NRORG
              )";
        
        $nmFornNfe = $this->removeAcentos($nmFornNfe);
        $nmFornNfe = substr($nmFornNfe, 0, 40);
        
        $params = array("P_NRACESSONFELOG"    => $nrAcessoNFe,
                        "P_DSINCONSNFELOG"    => $dsIncons,
                        "P_NMARQNFELOG"       => $nmArqNf,
                        "P_NRNOTANFELOG"      => $nrNotaNf,
                        "P_CDSERIENFELOG"     => $cdSerieNfe,
                        "P_CDFORNNFELOG"      => $cdFornNfe,
                        "P_NMFORNNFELOG"      => $nmFornNfe,
                        "NRORG"             => $this->organizacao);
        
		$params = $this->adicionaCampos($params, true);
        
        $std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);
    }
    
    public function verificaNotaImportada($nrAcessoNFe) {
    	$sql = "SELECT NRACESSONFE,
				  IDSTATUSNFE
				FROM INTG_NOTAFISCAL
				WHERE NRACESSONFE = :P_NRACESSONFE";
				
		$params = array("P_NRACESSONFE" => $nrAcessoNFe);
             
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return (isset($std->fetchAll()[0])) ? true : false; 
    }
    
	/*    public function getCertificado($sgEstado, $cdInscesta) {
    	$sql = "SELECT CDINSCESTA,
				  NRSERIECERTIFIC,
				  SGESTADO
				FROM INSCRESTAD
				WHERE (SGESTADO = :P_SGESTADO)
				AND (CDINSCESTA = :P_CDINSCESTA)
				ORDER BY CDINSCESTA";
				
		$params = array("P_SGESTADO"   => $sgEstado,
						"P_CDINSCESTA" => $cdInscesta);
						
		$std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetchAll(); 
    }*/
    
    public function verificaManifestacao($nrAcessoNFe){
    	$sql = "SELECT IDSTATUSNFE,
			  IDSTATUSMANIF,
			  CDDIGESTVALUE
			FROM NOTADESTINADA
			WHERE NRACESSONFE = :P_NRACESSONFE";
			
		$params = array("P_NRACESSONFE"   => $nrAcessoNFe);
						
		$std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetchAll(); 
    }
    
    public function getEmpresaPorCnpj($cnpj) {
    	$sql = "SELECT * FROM EMPRESA WHERE NRINSJUREMPR = :P_NRINSJUREMPR";
    	
    	$params = array("P_NRINSJUREMPR"   => $cnpj);
						
		$std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetchAll(); 
    }
    
    public function getFornecedor($cdFornecedor) {
    	$sql = "SELECT CDFORNECED, IDTPIJURFORN, IDFORNIMPXML, IDIMPLOTEXML
		        FROM FORNECEDOR
		       WHERE NRINSJURFORN = :P_NRINSJURFORN";
		      
		$params = array("P_NRINSJURFORN"   => $cdFornecedor);
						
		$std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetchAll(); 
    }
    
    public function verificaRaiz($raiz) {
    	$sql = "SELECT NRINSJUREMPR
				FROM EMPRESA
				WHERE SUBSTR(NRINSJUREMPR,1,8) = :P_RAIZ";
		
		$params = array("P_RAIZ"   => $raiz);
		
		$std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return isset($std->fetchAll()[0]);
    }
    
    public function getCadAutFornecedor() {
    	$sql = "SELECT IDCADAUTFORNECED
				FROM PARAMINTEGRA";
		
		$std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute();
        return $std->fetchAll()[0];
    }
      
    public function insereFornecedor($codFornecedor,$idTpijurforn,$nrInsjurforn,$nome,$nomeFantasia,$nrIscest,$nrorg) {
		$sql = "INSERT INTO FORNECEDOR
		    (CDFORNECED,
		    IDTPIJURFORN,
		    NRINSJURFORN,
		    NMRAZSOCFORN,
		    NMFANTFORN,
		    NRINSESTFORN,
		    NRINSMUNFORN,
		    DTULTCMPFORN,
		    IDTPDESCFORN,
		    VRPEDESCFORN,
		    IDTIPOFORN,
		    IDTPFRETFORN,
		    QTCNDPG1FORN,
		    QTCNDPG2FORN,
		    QTCNDPG3FORN,
		    QTCNDPG4FORN,
		    QTCNDPG5FORN,
		    QTCNDPG6FORN,
		    IDFORMPGFORN,
		    CDCSTDIG1ENT,
		    VRPERCINSS,
		    DTCADAFORN,
		    IDSITUCADA,
		    CDCONTCTBL,
		    DSNOMCHQFORN,
		    VRPERPG1FORN,
		    VRPERPG2FORN,
		    VRPERPG3FORN,
		    VRPERPG4FORN,
		    VRPERPG5FORN,
		    VRPERPG6FORN,
		    NRNOTAFORN,
		    CDQUALIF,
		    DTVALQUALIF,
		    CDMODDOCFISC,
		    CDFORMPGTO,
		    IDTPFORPGTFO,
		    NRPARCPGTOFO,
		    NRDIAPGFIXFO,
		    IDUTDIAPGTFO,
		    CDTIPCOB,
		    VRMINAUTFOR,
		    QTMINAUTFOT,
		    SGUNIDADE,
		    IDGERAFDTENT,
		    NRITEMAF,
		    IDGERCONTPGT,
		    IDFORNAUTO,
		    CDTPCTPAGAR,
		    IDENDEMISFOR,
		    IDENDCFOPFOR,
		    CDSENHAFOR,
		    DTULTATUFORN,
		    DSEMAILCOT,
		    CDAJUCTPAG,
		    CDTIPOFORN,
		    DSHOMEPAFOR,
		    IDFORNCONTRI,
		    CDCFOPFORN,
		    DSCFOPFORN,
		    CDGRUPOFISC,
		    CDEXFORNECED,
		    IDPRIPUBFORN,
		    IDAGRUBOLFOR,
		    IDLIGEXTFORN,
		    VRPERPIFORN,
		    DTINIVRPDESC,
		    CDTPBAIXAPAG,
		    IDFORNINTER,
		    CDSEGMER,
		    VRADIANTFORN,
		    CDGRUPFORN,
		    CDCLIENTE,
		    DSMAILCOTCOP,
		    IDUTILZIPAF,
		    NMCOMPRZSFOR,
		    IDEANPRODMAR,
		    IDTPENVAFFOR,
		    IDUTILEDINF,
		    IDOBRIGAEAN,
		    VRFRETEFORN,
		    IDCONTRAFORN,
		    IDPERCMPDFE,
		    CDFORNERELAC,
		    VRPERVARPREC,
		    IDUTQTDISPFORN,
		    IDBLOQCMPSAFFOR,
		    NRINSCSUFRAMAFO,
		    DSEMAILPEDCOLFO,
		    DSMAILPEDCOLCOP,
		    IDLOCALFORNCAD,
		    DTNASCPROFI,
		    IDSEXOPROFI,
		    NRRGPROFI,
		    IDPROFIPOSSVEIC,
		    IDAVALIAPROFI,
		    IDNPERMANCOTINT,
		    IDCOMPARQXMLFOR,
		    CDOPERGESTOR,
		    NRORG,
		    DTINCLUSAO,
		    DTULTATU,
		    NRORGINCLUSAO,
		    CDOPERINCLUSAO,
		    NRORGULTATU,
		    CDOPERULTATU,
		    IDTIPOPAGAPROF,
		    NRALVARAFORN,
		    DTALVARAFORN,
		    IDUTLALVFORN,
		    NRTELSUPORTEFOR,
		    DSEMAILPGTOFOR,
		    DSEMAILAFFOR,
		    IDTPENVAFNORMAL,
		    IDCONSFINAL,
		    NRPARCNEGOCIO,
		    IDATIVO,
		    CDFORNERELACAF,
		    IDVERPLANLOGI,
		    IDFORTRANSPVALE,
		    CDINTEGRAVAB,
		    DSEMAILAFFO,
		    DSEMAILAFCOP,
		    CDSENHAAFFOR,
		    DSEMAILCRFO,
		    DSEMAILCRCOP,
		    CDSENHACRFOR,
		    IDFORNIMPXML,
		    CDRECEFORN,
		    DTEXPFORNSAGA,
		    IDCONTRIBICMS,
		    VRPERVARDESCPREC,
		    DSDIRLOGOMARCA,
		    IDIMPPEDIDO_EXT,
		    IDTPTITULOCRED,
		    DSTPTITULOCRED,
		    DSLOCFOTOPROFORE,
		    IDINDCPRB,
		    CDDIGVERIFINTFOR,
		    IDTIPODOCINTFOR,
		    IDFORNPRODRURAL,
		    IDTPFORN,
		    IDUTLCONFIMATENDAF,
		    DSEMAILNOTIFATENDAF,
		    DTEXPXMLPROT,
		    IDGERAAJUSTEAFNF,
		    CDAJCTPAGDIFAFNF,
		    DSFOTOFORNFILESERV,
		    IDUTLCTRLTERMO,
		    IDPERALTAFCONF,
		    DSTOKENINTGECO,
		    IDIMPLOTEXML,
		    IDDISTRIBUIDOR,
		    IDCADIMPORTXML
		    )
			VALUES(
				:CDFORNECED,
		        :IDTPIJURFORN,
		        :NRINSJURFORN,
		        :NMRAZSOCFORN,
		        :NMFANTFORN,
		        :NRINSESTFORN,
		        null,
		        null,
		        null,
		        null,
		        'N',
		        null,
		        null,
		        null,
		        null,
		        null,
		        null,
		        null,
		        null,
		        '0',
		        null,
		        SYSDATE,
		        'A',
		        null,
		        null,
		        null,
		        null,
		        null,
		        null,
		        null,
		        null,
		        null,
		        null,
		        null,
		        null,
		        null,
		        null,
		        null,
		        null,
		        null,
		        null,
		        null,
		        null,
		        null,
		        null,
		        null,
		        'S',
		        'N',
		        null,
		        'P',
		        'P',
		        null,
		        SYSDATE,
		        null,
		        null,
		        null,
		        null,
		        'S',
		        null,
		        null,
		        null,
		        null,
		        'V',
		        'N',
		        'S',
		        null,
		        null,
		        null,
		        'N',
		        null,
		        null,
		        null,
		        null,
		        null,
		        'S',
		        null,
		        'N',
		        '1',
		        'N',
		        'N',
		        null,
		        'N',
		        'N',
		        null,
		        null,
		        'N',
		        'S',
		        null,
		        null,
		        null,
		        'F',
		        null,
		        'I',
		        null,
		        'N',
		        '0',
		        'N',
		        'S',
		        null,
		        :NRORG,
		        SYSDATE,
		        null,
		        1, 
		        '1',
		        1,
		        '1',
		        'CONTAPAGAR',
		        null,
		        null,
		        'N',
		        null,
		        null,
		        null,
		        null,
		        'N',
		        null,
		        'S',
		        null,
		        null,
		        'N',
		        null,
		        null,
		        null,
		        null,
		        null,
		        null,
		        null,
		        'S',
		        null,
		        null,
		        'N',
		        null,
		        null,
		        null,
		        'XX',
		        null,
		        null,
		        '0',
		        null,
		        null,
		        'N',
		        'G',
		        'N',
		        null,
		        null,
		        'N',
		        null,
		        null,
		        'N',
		        'N',
		        null,
		        'N',
		        'N',
		        'S')";
			        
		$params = array("CDFORNECED" => $codFornecedor,
						"IDTPIJURFORN" => $idTpijurforn,
						"NRINSJURFORN" => $nrInsjurforn,
						"NMRAZSOCFORN" => $nome,
						"NMFANTFORN" => $nomeFantasia,
						"NRINSESTFORN" => $nrIscest,
						"NRORG" => $nrorg);
						
		$std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);	
        
    }
    public function insereEndFornecedor($codFornecedor,$cdPais,$sgEstado,$cdMunicipio,$dsEndForn,$nmBairro,$nrCep,$nrorg) {
		$sql = "INSERT INTO ENDEFORN
			    (CDFORNECED,
			    IDTPENDEFORN,
			    CDPAIS,
			    SGESTADO,
			    CDMUNICIPIO,
			    DSENDEFORN,
			    NMBAIRFORN,
			    NRCEPFORN,
			    NRTELEFORN,
			    NRRAMALFORN,
			    NRTELEXFORN,
			    NRFAXFORN,
			    NMCONTFORN,
			    DSEMAILFORN,
			    DTULTATUENFO,
			    NRTELEFORN1,
			    NRRAMALFORN1,
			    NRCELULARFOR,
			    NRTELRESIFOR,
			    DSCOMPENDFOR,
			    CDLOGRADOURO,
			    NRENDEFORNSEP,
			    DSENDEFORNSEP,
			    NRDDDTELEFORN,
			    NRDDDTELEFORN1,
			    NRDDDCELULARFOR,
			    NRDDDTELRESIFOR,
			    NRDDDFAXFORN,
			    NRTELEFORNSEP,
			    NRTELEFORN1SEP,
			    NRCELULARFORSEP,
			    NRTELRESIFORSEP,
			    NRFAXFORNSEP,
			    DSEMAILFORNNFE,
			    NRENDERECOPARC,
			    DTINCLUSAO,
			    DTULTATU,
			    NRORGINCLUSAO,
			    CDOPERINCLUSAO,
			    NRORGULTATU,
			    CDOPERULTATU,
			    IDATIVO,
			    DSEMAILFORNCTE,
			    DSEMAILFORNMDFE,
			    NRORG
			    )
				VALUES(
					:CDFORNECED,
			        :IDTPENDEFORN,
			        (SELECT CDPAIS FROM PAIS WHERE CDPAISBACEN = :CDPAIS),
			        :SGESTADO,
			        (SELECT CDMUNICIPIO FROM MUNICIPIO WHERE CDMUNICIBGE = :CDMUNICIPIO),
			        :DSENDEFORN,
			        :NMBAIRFORN,
			        :NRCEPFORN,
			        null,
			        null,
			        null,
			        null,
			        null,
			        null,
			        SYSDATE,
			        null,
			        null,
			        null,
			        null,
			        null,
			        null,
			        null,
			        null,
			        null,
			        null,
			        null,
			        null,
			        null,
			        null,
			        null,
			        null,
			        null,
			        null,
			        null,
			        null,
			        SYSDATE,
			        SYSDATE,
			        null,
			        null,
			        null,
			        null,
			        'S',
			        null,
			        null,
			        :NRORG)";
			        
		$params = array("CDFORNECED" => $codFornecedor,
						"IDTPENDEFORN" => 'P',
						"CDPAIS" => $cdPais,
						"SGESTADO" => $sgEstado,
						"CDMUNICIPIO" => $cdMunicipio,
						"DSENDEFORN" => $dsEndForn,
						"NMBAIRFORN" => $nmBairro,
						"NRCEPFORN" => $nrCep,
						"NRORG" => $nrorg);
						
		$std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);	
        
    }
    public function insereSerie($cdSerie,$dsSerie,$nrorg) {
		$sql = "INSERT INTO SERIEENTR
				(CDSERIEENTR,
				DSSERIEENTR,
				DTULTATUSENT,
				IDGERACTBXP,
				CDSERIEENTRNFE,
				CDSERIEENTSCAN,
				DTINCLUSAO,
				DTULTATU,
				NRORGINCLUSAO,
				CDOPERINCLUSAO,
				NRORGULTATU,
				CDOPERULTATU,
				IDATIVO,
				NRORG,
				IDCADIMPORTXML
				)
				VALUES(
				:CDSERIEENTR,
				:DSSERIEENTR,
				SYSDATE,
				'N',
				null,
				null,
				SYSDATE,
				SYSDATE,
				null,
				null,
				null,
				null,
				'S',
				:NRORG,
				'S')";
			        
		$params = array("CDSERIEENTR" => $cdSerie,
						"DSSERIEENTR" => $dsSerie,
						"NRORG" => $nrorg);
						
		$std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);	
        
    }
    
    public function insereDadosAdic($nracessonfe,$dsDadoAdic,$nrorg) {
		$sql = "INSERT INTO INTG_DADOSADIC
				(NRACESSONFE,
				DSDADOADICXML,
			    NRORG
				)
				VALUES(
				:NRACESSONFE,
				:DSDADOADICXML,
				:NRORG)";
			        
		$params = array("NRACESSONFE" => $nracessonfe,
						"DSDADOADICXML" => $dsDadoAdic,
						"NRORG" => $nrorg);
						
		$std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);	
        
    }
    
    public function dadosAdic_XML($nracessonfe, $nrorg) {
    	$sql = "SELECT DSDADOADICXML 
    	          FROM INTG_DADOSADIC 
				 WHERE NRACESSONFE = :NRACESSONFE
				   AND NRORG = :NRORG";
            
    	$params = array("NRACESSONFE" => $nracessonfe, "NRORG" => $nrorg);
		
		$std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
        
    }
    
    public function getCdPais($cdMunicipio) {
    	$sql = "SELECT CDPAIS
             FROM MUNICIPIO
            WHERE CDMUNICIBGE = :CDMUNICIPIO";
            
    	$params = array("CDMUNICIPIO"   => $cdMunicipio);
		
		$std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetchAll()[0];
        
    }
    
    public function getCadAutSerie() {
    	$sql = "SELECT IDCADAUTSERIE
				FROM PARAMINTEGRA";
		
		$std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute();
        return $std->fetchAll()[0];
    }
    
    public function verificaSerieExiste($cdSerie) {
    	$sql = "SELECT CDSERIEENTR, DSSERIEENTR 
             FROM SERIEENTR
            WHERE CDSERIEENTR = :P_CDSERIEENTR";
            
    	$params = array("P_CDSERIEENTR"   => $cdSerie);
		
		$std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return isset($std->fetchAll()[0]);
    }
    
    public function verificaExisteFilial($cdFilial) {
        $sql = "SELECT CDFILIAL 
				FROM FILIAL 
				WHERE CDFILIAL = :P_CDFILIAL";
				
		$params = array("P_CDFILIAL"   => $cdFilial);
		
		$std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return isset($std->fetchAll()[0]);
    }
    
    public function insereIntgNotaFiscal($cdfilial, $nrlanctonf, $cdempresa, $cdinscesta, $idtpijurnf, $nrinsjurnf, $cdforneced, $nrnotafisc, $dtemissao, $dtentrsaid, $vrprodutos, $vrnotafisc, $cdserieentr, $cdfilirece, $idimportada, $dtlancamennf, $nracessonfe, $idstatusnfe, $dthrprotocolnfe, $idtpambnfe, $idtipoemisnfe, $nrprotocolonfe, $dsobsstatusnfe, $cdmoddocfisc, $dsnomearquxml, $nrinsjurempr, $nrInsJurTranxml, $nrPlacaVeicXml, $sgUfVeicXml,  $qtDevoluXml, $especVoluXml, $marcaVoluXml, $numeroVoluXml, $vrPBrutoVoluXml, $vrPLiqVoluXml, $idPgtoFreteXml, $nrorg) {
    	
    	$sql = "INSERT INTO INTG_NOTAFISCAL
			      (	CDFILIAL,
					NRLANCTONF,
					CDEMPRESA,
					CDINSCESTA,
					IDTPIJURNF,
					NRINSJURNF,
					CDFORNECED,
					NRNOTAFISC,
					DTEMISSAO,
					DTENTRSAID,
					VRPRODUTOS,
					VRNOTAFISC,
					CDSERIEENTR,
					CDFILIRECE,
					IDIMPORTADA,
					DTLANCAMENNF,
					NRACESSONFE,
					IDSTATUSNFE,
					DTHRPROTOCOLNFE,
					IDTPAMBNFE,
					IDTIPOEMISNFE,
					NRPROTOCOLONFE,
					DSOBSSTATUSNFE,
					CDMODDOCFISC,
					DTIMPORTACAOXML,
					DSNOMEARQUXML,
					IDARQXMLNFE,
					NRINSJUREMPR,
					NRINSJURTRANXML,				
					NRPLACAVEICXML,				
					SGUFVEICXML,				
					IDPGTOFRETEXML,				
					DSQTDEVOLUXML,				
					DSESPECVOLUXML,				
					DSMARCAVOLUXML,				
					DSNUMEVOLUXML,				
					VRPBRUTOVOLUXML,				
					VRPLIQUVOLUXML,	
					DTINCLUSAO,
					CDOPERINCLUSAO,
					NRORGINCLUSAO,
					IDATIVO,
					DTULTATU,
					NRORGULTATU,
					CDOPERULTATU,
					NRORG
			       )
			      VALUES
			      (:CDFILIAL,
			       :NRLANCTONF,
			       :CDEMPRESA,
			       :CDINSCESTA,
			       :IDTPIJURNF,
			       :NRINSJURNF,
			       :CDFORNECED,
			       :NRNOTAFISC,
			       :DTEMISSAO,
			       :DTENTRSAID,
			       :VRPRODUTOS,
			       :VRNOTAFISC,
			       :CDSERIEENTR,
			       :CDFILIRECE,
			       :IDIMPORTADA,
			       :DTLANCAMENNF,
			       :NRACESSONFE,
			       :IDSTATUSNFE,
			       :DTHRPROTOCOLNFE,
			       :IDTPAMBNFE,
			       :IDTIPOEMISNFE,
			       :NRPROTOCOLONFE,
			       :DSOBSSTATUSNFE,
			       :CDMODDOCFISC,
			       SYSDATE,
			       :DSNOMEARQUXML,
			       'N',
			       :NRINSJUREMPR,
				   :NRINSJURTRANXML,				
				   :NRPLACAVEICXML,				
				   :SGUFVEICXML,				
				   :IDPGTOFRETEXML,				
				   :DSQTDEVOLUXML,				
				   :DSESPECVOLUXML,				
				   :DSMARCAVOLUXML,				
				   :DSNUMEVOLUXML,				
				   :VRPBRUTOVOLUXML,				
				   :VRPLIQUVOLUXML,	
				   :DTINCLUSAO,
				   :CDOPERINCLUSAO,
				   :NRORGINCLUSAO,
				   :IDATIVO,
				   :DTULTATU,
				   :NRORGULTATU,
				   :CDOPERULTATU,
			       :NRORG)";
			       
		$params = array("CDFILIAL" => $cdfilial,
						"NRLANCTONF" => $nrlanctonf,
						"CDEMPRESA" => $cdempresa,
						"CDINSCESTA" => $cdinscesta,
						"IDTPIJURNF" => $idtpijurnf,
						"NRINSJURNF" => $nrinsjurnf,
						"CDFORNECED" => $cdforneced,
						"NRNOTAFISC" => $nrnotafisc,
						"DTEMISSAO" => $dtemissao,
						"DTENTRSAID" => $dtentrsaid,
						"VRPRODUTOS" => $vrprodutos,
						"VRNOTAFISC" => $vrnotafisc,
						"CDSERIEENTR" => $cdserieentr,
						"CDFILIRECE" => $cdfilirece,
						"IDIMPORTADA" => $idimportada,
						"DTLANCAMENNF" => $dtlancamennf,
						"NRACESSONFE" => $nracessonfe,
						"IDSTATUSNFE" => $idstatusnfe,
						"DTHRPROTOCOLNFE" => $dthrprotocolnfe,
						"IDTPAMBNFE" => $idtpambnfe,
						"IDTIPOEMISNFE" => $idtipoemisnfe,
						"NRPROTOCOLONFE" => $nrprotocolonfe,
						"DSOBSSTATUSNFE" => $dsobsstatusnfe,
						"CDMODDOCFISC" => $cdmoddocfisc,
						"DSNOMEARQUXML" => $dsnomearquxml,
						"NRINSJUREMPR" => $nrinsjurempr,
						"NRINSJURTRANXML" => $nrInsJurTranxml,
						"NRPLACAVEICXML" => $nrPlacaVeicXml,
						"SGUFVEICXML" => $sgUfVeicXml,
						"IDPGTOFRETEXML" => $idPgtoFreteXml,
						"DSQTDEVOLUXML" => $qtDevoluXml,
						"DSESPECVOLUXML" => $especVoluXml,
						"DSMARCAVOLUXML" => $marcaVoluXml,
						"DSNUMEVOLUXML" => $numeroVoluXml,
						"VRPBRUTOVOLUXML" => $vrPBrutoVoluXml,
						"VRPLIQUVOLUXML" => $vrPLiqVoluXml,
						"NRORG" => $nrorg);

		
		$params = $this->adicionaCampos($params, true);
		$std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);
        
       
			       
    }
    
    public function insereIntgNotaFiscalNFSe($cdfilial, $nrlanctonf, $cdempresa, $cdinscesta, $idtpijurnf, $nrinsjurnf, $cdforneced, $nrnotafisc, $dtemissao, $dtentrsaid, $vrprodutos, $vrnotafisc, $cdserieentr, $cdfilirece, $idimportada, $dtlancamennf, $nracessonfe, $idstatusnfe, $dthrprotocolnfe, $idtpambnfe, $idtipoemisnfe, $nrprotocolonfe, $dsobsstatusnfe, $cdmoddocfisc, $dsnomearquxml, $nrinsjurempr, $nrInsJurTranxml, $nrPlacaVeicXml, $sgUfVeicXml,  $qtDevoluXml, $especVoluXml, $marcaVoluXml, $numeroVoluXml, $vrPBrutoVoluXml, $vrPLiqVoluXml, $idPgtoFreteXml, $iddocfiscele, $nrorg) {
    	$sql = "INSERT INTO INTG_NOTAFISCAL
			      (	CDFILIAL,
					NRLANCTONF,
					CDEMPRESA,
					CDINSCESTA,
					IDTPIJURNF,
					NRINSJURNF,
					CDFORNECED,
					NRNOTAFISC,
					DTEMISSAO,
					DTENTRSAID,
					VRPRODUTOS,
					VRNOTAFISC,
					CDSERIEENTR,
					CDFILIRECE,
					IDIMPORTADA,
					DTLANCAMENNF,
					NRACESSONFE,
					IDSTATUSNFE,
					DTHRPROTOCOLNFE,
					IDTPAMBNFE,
					IDTIPOEMISNFE,
					NRPROTOCOLONFE,
					DSOBSSTATUSNFE,
					CDMODDOCFISC,
					DTIMPORTACAOXML,
					DSNOMEARQUXML,
					IDARQXMLNFE,
					NRINSJUREMPR,
					NRINSJURTRANXML,				
					NRPLACAVEICXML,				
					SGUFVEICXML,				
					IDPGTOFRETEXML,				
					DSQTDEVOLUXML,				
					DSESPECVOLUXML,				
					DSMARCAVOLUXML,				
					DSNUMEVOLUXML,				
					VRPBRUTOVOLUXML,				
					VRPLIQUVOLUXML,	
					DTINCLUSAO,
					CDOPERINCLUSAO,
					NRORGINCLUSAO,
					IDATIVO,
					DTULTATU,
					NRORGULTATU,
					CDOPERULTATU,
					IDDOCFISCELE,
					NRORG
			       )
			      VALUES
			      (:CDFILIAL,
			       :NRLANCTONF,
			       :CDEMPRESA,
			       :CDINSCESTA,
			       :IDTPIJURNF,
			       :NRINSJURNF,
			       :CDFORNECED,
			       :NRNOTAFISC,
			       :DTEMISSAO,
			       :DTENTRSAID,
			       :VRPRODUTOS,
			       :VRNOTAFISC,
			       :CDSERIEENTR,
			       :CDFILIRECE,
			       :IDIMPORTADA,
			       :DTLANCAMENNF,
			       :NRACESSONFE,
			       :IDSTATUSNFE,
			       :DTHRPROTOCOLNFE,
			       :IDTPAMBNFE,
			       :IDTIPOEMISNFE,
			       :NRPROTOCOLONFE,
			       :DSOBSSTATUSNFE,
			       :CDMODDOCFISC,
			       SYSDATE,
			       :DSNOMEARQUXML,
			       'N',
			       :NRINSJUREMPR,
				   :NRINSJURTRANXML,				
				   :NRPLACAVEICXML,				
				   :SGUFVEICXML,				
				   :IDPGTOFRETEXML,				
				   :DSQTDEVOLUXML,				
				   :DSESPECVOLUXML,				
				   :DSMARCAVOLUXML,				
				   :DSNUMEVOLUXML,				
				   :VRPBRUTOVOLUXML,				
				   :VRPLIQUVOLUXML,	
				   :DTINCLUSAO,
				   :CDOPERINCLUSAO,
				   :NRORGINCLUSAO,
				   :IDATIVO,
				   :DTULTATU,
				   :NRORGULTATU,
				   :CDOPERULTATU,
				   :IDDOCFISCELE,
			       :NRORG)";
			       
		$params = array("CDFILIAL" => $cdfilial,
						"NRLANCTONF" => $nrlanctonf,
						"CDEMPRESA" => $cdempresa,
						"CDINSCESTA" => $cdinscesta,
						"IDTPIJURNF" => $idtpijurnf,
						"NRINSJURNF" => $nrinsjurnf,
						"CDFORNECED" => $cdforneced,
						"NRNOTAFISC" => $nrnotafisc,
						"DTEMISSAO" => $dtemissao,
						"DTENTRSAID" => $dtentrsaid,
						"VRPRODUTOS" => $vrprodutos,
						"VRNOTAFISC" => $vrnotafisc,
						"CDSERIEENTR" => $cdserieentr,
						"CDFILIRECE" => $cdfilirece,
						"IDIMPORTADA" => $idimportada,
						"DTLANCAMENNF" => $dtlancamennf,
						"NRACESSONFE" => $nracessonfe,
						"IDSTATUSNFE" => $idstatusnfe,
						"DTHRPROTOCOLNFE" => $dthrprotocolnfe,
						"IDTPAMBNFE" => $idtpambnfe,
						"IDTIPOEMISNFE" => $idtipoemisnfe,
						"NRPROTOCOLONFE" => $nrprotocolonfe,
						"DSOBSSTATUSNFE" => $dsobsstatusnfe,
						"CDMODDOCFISC" => $cdmoddocfisc,
						"DSNOMEARQUXML" => $dsnomearquxml,
						"NRINSJUREMPR" => $nrinsjurempr,
						"NRINSJURTRANXML" => $nrInsJurTranxml,
						"NRPLACAVEICXML" => $nrPlacaVeicXml,
						"SGUFVEICXML" => $sgUfVeicXml,
						"IDPGTOFRETEXML" => $idPgtoFreteXml,
						"DSQTDEVOLUXML" => $qtDevoluXml,
						"DSESPECVOLUXML" => $especVoluXml,
						"DSMARCAVOLUXML" => $marcaVoluXml,
						"DSNUMEVOLUXML" => $numeroVoluXml,
						"VRPBRUTOVOLUXML" => $vrPBrutoVoluXml,
						"VRPLIQUVOLUXML" => $vrPLiqVoluXml,
						"IDDOCFISCELE" => $iddocfiscele,
						"NRORG" => $nrorg);

		
		$params = $this->adicionaCampos($params, true);
		$std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);
        
       
			       
    }
    public function atualizaNotaEstornada($nrAcessoNFe) {
    	$sql = "UPDATE INTG_NOTAFISCAL
				SET IDSTATUSNFE            = 'E',
                       DTULTATU    = :DTULTATU,
					   NRORGULTATU  = :NRORGULTATU,
					   CDOPERULTATU = :CDOPERULTATU
				WHERE NRACESSONFE          = :P_NRACESSONFE
				AND IDSTATUSNFE           <> 'U'
				AND NVL(IDIMPORTADA, 'N') <> 'S'";
				
		$params = array("P_NRACESSONFE"    => $nrAcessoNFe);
		$params = $this->adicionaCampos($params, false);
        
        $std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);
    }
    
    public function buscaNotaFiscalImportada($nrAcessoNFe) {
    	$sql = "SELECT NRACESSONFE, IDSTATUSNFE
				FROM INTG_NOTAFISCAL
				WHERE NRACESSONFE = :P_NRACESSONFE";
		
		$params = array("P_NRACESSONFE"    => $nrAcessoNFe);
        
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetchAll(); 
    }
    
    public function insereIntgItemEncargo($cdfilial, $nrlanctonf, $cdencargo, $vritemenca, $nracessonfe, $nrorg) {
    	$sql = "INSERT
				INTO INTG_ITEMENCARGO
				  (
				    CDFILIAL,
				    NRLANCTONF,
				    CDENCARGO,
				    VRITEMENCA,
				    NRACESSONFE,
				    DTINCLUSAO,
					CDOPERINCLUSAO,
					NRORGINCLUSAO,
					IDATIVO,
					DTULTATU,
					NRORGULTATU,
					CDOPERULTATU,
				    NRORG
				  )
				  VALUES
				  (
				    :CDFILIAL,
				    :NRLANCTONF,
				    :CDENCARGO,
				    :VRITEMENCA,
				    :NRACESSONFE,
				    :DTINCLUSAO,
					:CDOPERINCLUSAO,
					:NRORGINCLUSAO,
					:IDATIVO,
					:DTULTATU,
					:NRORGULTATU,
					:CDOPERULTATU,
				    :NRORG
				  )";
				  
		$params = array("CDFILIAL" => $cdfilial,
						"NRLANCTONF" => $nrlanctonf,
						"CDENCARGO" => $cdencargo,
						"VRITEMENCA" => $vritemenca,
						"NRACESSONFE" => $nracessonfe,
						"NRORG" => $nrorg);
						
		
		$params = $this->adicionaCampos($params, true);
        
        $std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);
    }
    
    public function insereIntgContaPagar($cdfilial, $nrlanctonf, $nrseqvenpag, $nrparcelapag, $cdtpctpagar, $qtdiasvenpag, $dtorigvenpag, $vrorigpag, $cdempresa, $nracessonfe, $nrorg) {
    	$sql = "INSERT
				INTO INTG_CONTAPAGAR
				  (
				    CDFILIAL,
				    NRLANCTONF,
				    NRSEQVENPAG,
				    NRPARCELAPAG,
				    CDTPCTPAGAR,
				    QTDIASVENPAG,
				    DTORIGVENPAG,
				    VRORIGPAG,
				    CDEMPRESA,
				    NRACESSONFE,
				    DTINCLUSAO,
					CDOPERINCLUSAO,
					NRORGINCLUSAO,
				    IDATIVO,
				    DTULTATU,
				    NRORGULTATU,
				    CDOPERULTATU,
				    NRORG
				  )
				  VALUES
				  (
				    :CDFILIAL,
				    :NRLANCTONF,
				    :NRSEQVENPAG,
				    :NRPARCELAPAG,
				    :CDTPCTPAGAR,
				    :QTDIASVENPAG,
				    :DTORIGVENPAG,
				    :VRORIGPAG,
				    :CDEMPRESA,
				    :NRACESSONFE,
				    :DTINCLUSAO,
					:CDOPERINCLUSAO,
					:NRORGINCLUSAO,
					:IDATIVO,
					:DTULTATU,
					:NRORGULTATU,
					:CDOPERULTATU,
				    :NRORG
				  )";
				  
		$params = array("CDFILIAL" => $cdfilial,
						"NRLANCTONF" => $nrlanctonf,
						"NRSEQVENPAG" => $nrseqvenpag,
						"NRPARCELAPAG" => $nrparcelapag,
						"CDTPCTPAGAR" => $cdtpctpagar,
						"QTDIASVENPAG" => $qtdiasvenpag,
						"DTORIGVENPAG" => $dtorigvenpag,
						"VRORIGPAG" => $vrorigpag,
						"CDEMPRESA" => $cdempresa,
						"NRACESSONFE" => $nracessonfe,
						"NRORG" => $nrorg);
		
		
		$params = $this->adicionaCampos($params, true);
        
        $std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);
    }
    
    public function getTipoOperCfop($idEntrSaidOp, $cfop) {
    	$sql = "SELECT CDTIPOOPER
				FROM CFOPXMLTPOPER
				WHERE IDENTRSAIDOP = :P_IDENTRSAIDOP
				AND CDFISCOPER   = :P_CFOP";
				
		$params = array("P_IDENTRSAIDOP"	=> $idEntrSaidOp,
						"P_CFOP"			=> $cfop);
						
		$std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetchAll(); 
    }
    
    public function updateTipoOperNf($cdTipoOper, $nrAcessoNFe) {
    	$sql = "UPDATE INTG_NOTAFISCAL
				SET CDTIPOOPER  = :P_CDTIPOOPER,
                       DTULTATU    = :DTULTATU,
					   NRORGULTATU  = :NRORGULTATU,
					   CDOPERULTATU = :CDOPERULTATU
				WHERE NRACESSONFE = :P_NRACESSONFE";
				
		$params = array("P_CDTIPOOPER"	=> $cdTipoOper,
						"P_NRACESSONFE"	=> $nrAcessoNFe);
		$params = $this->adicionaCampos($params, false);
		
						
		$std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);
    }
     public function getCdProd($cdForneced, $cdProduto,$nrorg) {
    	$sql = "SELECT CDPRODUTO 
						FROM PRODFORNXML
						WHERE CDFORNECED   = :CDFORNECED
						AND CDPRODUTOXML   = :CDPRODUTOXML 
						AND NRORG =:NRORG";
				
		$params = array("CDFORNECED"	=> $cdForneced,
						"CDPRODUTOXML"	=> $cdProduto,
						"NRORG"		=> $nrorg);
						
		$std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
     public function getNcm($ncm, $nrorg) {
    	$sql = "SELECT CDCLASFISC 
    					FROM CLASFISCAL 
    					WHERE CDCLASFISC = :NCM
						AND NRORG =:NRORG";
				
		$params = array("NCM"	=> $ncm,
						"NRORG"		=> $nrorg);
						
		$std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function updateProduto($ncm,$cdProduto,$nrorg) {
    	$sql = "UPDATE PRODUTO
    				SET CDCLASFISC = :CDCLASFISC
					WHERE CDPRODUTO =:CDPRODUTO
    				AND CDCLASFISC is null
    				AND NRORG =:NRORG";
				
		$params = array("CDPRODUTO"	=> $cdProduto,
						"CDCLASFISC"=> $ncm,
						"NRORG"		=> $nrorg
						);
		
		$std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);
    }
    
    public function insereIntgItemProduto($cdfilial, $nrlanctonf, $nrseqitprod, $cdproduto, $nmproduto, $sgunidade, $qtitemprod, $vrunititem, $vrdescitem, $vrtotaitem, $vrbrutitem, $vrcontitem,
    									  $nrautoforn, $cdmarca, $dtprogentaf, $vrdesperitem, $cdfilimovi, $cdalmoxarife, $cdlocalestoq, $nracessonfe, $cdinfadprod, $cdfisopeitem, $cdclasfisc,
    									  $nrorg, $nLote = null, $dFab = null, $dVal = null, $cAgreg = null) {
    	$sql = "INSERT INTO INTG_ITEMPRODUTO
				      (CDFILIAL,
				       NRLANCTONF,
				       NRSEQITPROD,
				       CDPRODUTO,
				       NMPRODUTO,
				       SGUNIDADE,
				       QTITEMPROD,
				       VRUNITITEM,
				       VRDESCITEM,
				       VRTOTAITEM,
				       VRBRUTITEM,
				       VRCONTITEM,
				       NRAUTOFORN,
				       CDMARCA,
				       DTPROGENTAF,
				       VRDESPERITEM,
				       CDFILIMOVI,
				       CDALMOXARIFE,
				       CDLOCALESTOQ,
				       NRACESSONFE,
				       CDINFADPROD,
				       CDFISOPEITEM,
				       CDCLASFISC,
					   DTINCLUSAO,
					   CDOPERINCLUSAO,
					   NRORGINCLUSAO,
				       IDATIVO,
				       DTULTATU,
				       NRORGULTATU,
				       CDOPERULTATU,
				       NRORG,
				       NRLOTEPRODXML,
				       DTFABPRODXML,
				       DTVALPRODXML,
				       CDAGREGPRODXML
				)
				VALUES
				(
				       :CDFILIAL,
				       :NRLANCTONF,
				       :NRSEQITPROD,
				       :CDPRODUTO,
				       :NMPRODUTO,
				       :SGUNIDADE,
				       :QTITEMPROD,
				       :VRUNITITEM,
				       :VRDESCITEM,
				       :VRTOTAITEM,
				       :VRBRUTITEM,
				       :VRCONTITEM,
				       :NRAUTOFORN,
				       :CDMARCA,
				       :DTPROGENTAF,
				       :VRDESPERITEM,
				       :CDFILIMOVI,
				       :CDALMOXARIFE,
				       :CDLOCALESTOQ,
				       :NRACESSONFE,
				       :CDINFADPROD,
				       :CDFISOPEITEM,
				       :CDCLASFISC,
				       :DTINCLUSAO,
					   :CDOPERINCLUSAO,
					   :NRORGINCLUSAO,
					   :IDATIVO,
					   :DTULTATU,
					   :NRORGULTATU,
					   :CDOPERULTATU,
				       :NRORG,
				       :NRLOTEPRODXML,
				       :DTFABPRODXML,
				       :DTVALPRODXML,
				       :CDAGREGPRODXML)";
    	
    	$params = array("CDFILIAL" => $cdfilial,
						"NRLANCTONF" => $nrlanctonf,
						"NRSEQITPROD" => $nrseqitprod,
						"CDPRODUTO" => $cdproduto,
						"NMPRODUTO" => $nmproduto,
						"SGUNIDADE" => $sgunidade,
						"QTITEMPROD" => $qtitemprod,
						"VRUNITITEM" => $vrunititem,
						"VRDESCITEM" => $vrdescitem,
						"VRTOTAITEM" => $vrtotaitem,
						"VRBRUTITEM" => $vrbrutitem,
						"VRCONTITEM" => $vrcontitem,
						"NRAUTOFORN" => $nrautoforn,
						"CDMARCA" => $cdmarca,
						"DTPROGENTAF" => $dtprogentaf,
						"VRDESPERITEM" => $vrdesperitem,
						"CDFILIMOVI" => $cdfilimovi,
						"CDALMOXARIFE" => $cdalmoxarife,
						"CDLOCALESTOQ" => $cdlocalestoq,
						"NRACESSONFE" => $nracessonfe,
						"CDINFADPROD" => $cdinfadprod,
						"CDFISOPEITEM" => $cdfisopeitem,
						"CDCLASFISC" => $cdclasfisc,
						"NRORG" => $nrorg,
						"NRLOTEPRODXML" => $nLote,
						"DTFABPRODXML" => $dFab,
						"DTVALPRODXML" => $dVal,
						"CDAGREGPRODXML" => $cAgreg
						);

		$params = $this->adicionaCampos($params, true);
		
		$std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);
    }

	public function buscaAutorizacaoFornecimento($nrAutoForn) {
		$sql = "SELECT MAX(CDFILDEST) AS CDFILDEST
				FROM AUTOFORNE
				WHERE NRAUTOFORN = :P_NRAUTOFORN";
		
		$params = array("P_NRAUTOFORN"	=> $nrAutoForn);
				
		$std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetchAll(); 
    }
    
    public function atualizaFilialRecebimento($cdfilial, $nracessonfe) {
    	$sql = "UPDATE INTG_NOTAFISCAL
				SET CDFILIRECE = :P_CDFILIAL,
                       DTULTATU    = :DTULTATU,
					   NRORGULTATU  = :NRORGULTATU,
					   CDOPERULTATU = :CDOPERULTATU
				WHERE NRACESSONFE = :P_NRACESSONFE";
    	
    	$params = array("P_CDFILIAL"	=> $cdfilial,
						"P_NRACESSONFE"	=> $nracessonfe);
		$params = $this->adicionaCampos($params, false);
		
						
		$std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);
    }
    
    public function buscaProduto($cdProduto) {
    	$sql = "SELECT CDPRODUTO
					 FROM PRODUTO
				WHERE CDPRODUTO = :P_CDPRODUTO";
    			
		$params = array("P_CDPRODUTO"	=> $cdProduto);
						
		$std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetchAll(); 
    }
    
    public function insereIntgTrabItProImpos($cdfilial, $nrlanctonf, $nrseqimpoit, $cdimpostoit, $vrcontitimp, $vrperredbcit, $vrbasecalcit, $vraliqitem, $vrimpostoit, $cdfiscalit, $cdsitutribit, $cdfiscoperit, $nritproimpos, $nracessonfe, $idmodbcitnfe, $idmodbcstitnfe, $pFcp, $vFcp, $nrorg) {
    
    	$sql = "INSERT INTO INTG_TRABITPROIMPOS
			      (CDFILIAL,
			       NRLANCTONF,
			       NRSEQIMPOIT,
			       CDIMPOSTOIT,
			       VRCONTITIMP,
			       VRPERREDBCIT,
			       VRBASECALCIT,
			       VRALIQITEM,
			       VRIMPOSTOIT,
			       CDFISCALIT,
			       CDSITUTRIBIT,
			       CDFISCOPERIT,
			       NRITPROIMPOS,
			       NRACESSONFE,
			       IDMODBCITNFE,
			       IDMODBCSTITNFE,
			       VRADICALIQFECP,
			       VRADICFECP,
				   DTINCLUSAO,
				   CDOPERINCLUSAO,
				   NRORGINCLUSAO,
				   IDATIVO,
				   DTULTATU,
				   NRORGULTATU,
				   CDOPERULTATU,
			       NRORG)
			      VALUES
			      (:CDFILIAL,
			       :NRLANCTONF,
			       :NRSEQIMPOIT,
			       :CDIMPOSTOIT,
			       :VRCONTITIMP,
			       :VRPERREDBCIT,
			       :VRBASECALCIT,
			       :VRALIQITEM,
			       :VRIMPOSTOIT,
			       :CDFISCALIT,
			       :CDSITUTRIBIT,
			       :CDFISCOPERIT,
			       :NRITPROIMPOS,
			       :NRACESSONFE,
			       :IDMODBCITNFE,
			       :IDMODBCSTITNFE,
			       :VRADICALIQFECP,
			       :VRADICFECP,
				   :DTINCLUSAO,
				   :CDOPERINCLUSAO,
				   :NRORGINCLUSAO,
				   :IDATIVO,
				   :DTULTATU,
				   :NRORGULTATU,
				   :CDOPERULTATU,
			       :NRORG)";
    	
    	$params = array("CDFILIAL" => $cdfilial,
						"NRLANCTONF" => $nrlanctonf,
						"NRSEQIMPOIT" => $nrseqimpoit,
						"CDIMPOSTOIT" => $cdimpostoit,
						"VRCONTITIMP" => $vrcontitimp,
						"VRPERREDBCIT" => $vrperredbcit,
						"VRBASECALCIT" => $vrbasecalcit,
						"VRALIQITEM" => $vraliqitem,
						"VRIMPOSTOIT" => $vrimpostoit,
						"CDFISCALIT" => $cdfiscalit,
						"CDSITUTRIBIT" => $cdsitutribit,
						"CDFISCOPERIT" => $cdfiscoperit,
						"NRITPROIMPOS" => $nritproimpos,
						"NRACESSONFE" => $nracessonfe,
						"IDMODBCITNFE" => $idmodbcitnfe,
						"IDMODBCSTITNFE" => $idmodbcstitnfe,
						"VRADICALIQFECP" => $pFcp,
						"VRADICFECP" => $vFcp,
						"NRORG" => $nrorg);
		
		$params = $this->adicionaCampos($params, true);
    	
    	$std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);
    }
    
    public function atualizaOrigemProd($origProd, $nrAcessoNfe, $nrSeqItProd) {
    	$sql = "UPDATE INTG_ITEMPRODUTO
				SET IDORIGEMPROD  = :IDORIGEMPROD,
                       DTULTATU    = :DTULTATU,
					   NRORGULTATU  = :NRORGULTATU,
					   CDOPERULTATU = :CDOPERULTATU
				WHERE NRACESSONFE = :NRACESSONFE
				AND NRSEQITPROD   = :NRSEQITPROD";
				
		$params = array("IDORIGEMPROD" => $origProd,
						"NRACESSONFE"  => $nrAcessoNfe, 
						"NRSEQITPROD"  => $nrSeqItProd);
		$params = $this->adicionaCampos($params, false);
		
						
		$std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);
    }
    
    public function updateCST($cst, $nrAcessoNfe, $nrSeqItProd) {
    	$sql = "UPDATE INTG_ITEMPRODUTO
        		SET CDSITUTRIBPR = :P_CST,
                       DTULTATU    = :DTULTATU,
					   NRORGULTATU  = :NRORGULTATU,
					   CDOPERULTATU = :CDOPERULTATU
    			WHERE NRACESSONFE  = :P_NRACESSONFE AND
            	NRSEQITPROD  = :P_NRSEQITPROD";
            	
        $params = array("P_CST" => $cst,
						"P_NRACESSONFE"  => $nrAcessoNfe, 
						"P_NRSEQITPROD"  => $nrSeqItProd);
		$params = $this->adicionaCampos($params, false);
		
						
		$std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);
    }
    
    public function buscaHistoricoXML($nrAcessoNfe) {
    	$sql = "SELECT NRACESSONFE, NRSEQHISTOR, DTHISTORICO, IDTIPOOPER, IDSTATUS, NRPROTOCOLONFE,
            	DSOPERACAO, CDFILIAL, NRLANCTONF, CDOPERADOR
		        FROM HISTXMLNFE
		       WHERE NRACESSONFE = :P_NRACESSONFE";
		 
		$params = array("P_NRACESSONFE"  => $nrAcessoNfe);
						
		$std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
		return $std->fetchAll(); 
    }
    
    public function getSequencialHistoricoXML($nrAcessoNfe) {
    	$sql = "SELECT MAX(NVL(NRSEQHISTOR,0)) AS NRSEQHISTOR
		        FROM HISTXMLNFE
		       WHERE NRACESSONFE = :P_NRACESSONFE";
		 
		$params = array("P_NRACESSONFE"  => $nrAcessoNfe);
						
		$std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
		return $std->fetchAll(); 
    }
    
    public function insereHistoricoXML($nrAcessoNfe, $nrSeqHistor, $dtHistorico, $idTipoOper, $idStatus, $nrProcoloNFe, $dsOperacao, $cdFilial, $nrLanctonf, $cdOperador, $nrOrg) {
    	$sql = "INSERT 
    			INTO HISTXMLNFE
    			(
    				NRACESSONFE, 
    				NRSEQHISTOR, 
    				DTHISTORICO, 
    				IDTIPOOPER,
                    IDSTATUS, 
                    NRPROTOCOLONFE, 
                    DSOPERACAO, 
                    CDFILIAL,
                	NRLANCTONF, 
                	CDOPERADOR, 
                	DTINCLUSAO, 
                	CDOPERINCLUSAO, 
                	NRORGINCLUSAO, 
					IDATIVO,
					DTULTATU,
					NRORGULTATU,
					CDOPERULTATU, 
					NRORG
				)
            	VALUES 
            	(
            		:NRACESSONFE, 
            		:NRSEQHISTOR, 
            		:DTHISTORICO, 
            		:IDTIPOOPER,
            		:IDSTATUS, 
            		:NRPROTOCOLONFE, 
            		:DSOPERACAO, 
            		:CDFILIAL,
            		:NRLANCTONF, 
            		:CDOPERADOR, 
            		:DTINCLUSAO, 
            		:CDOPERINCLUSAO, 
            		:NRORGINCLUSAO, 
					:IDATIVO,
					:DTULTATU,
					:NRORGULTATU,
					:CDOPERULTATU, 
					:NRORG
				)";
        
        $this->getSequencialHistoricoXML($nrAcessoNfe);     
              
        $params = array("NRACESSONFE"		=> $nrAcessoNfe,
						"NRSEQHISTOR"		=> $nrSeqHistor, 
						"DTHISTORICO"		=> $dtHistorico,
						"IDTIPOOPER"		=> $idTipoOper,
						"IDSTATUS"			=> $idStatus,
						"NRPROTOCOLONFE"	=> $nrProcoloNFe,
						"DSOPERACAO"		=> $dsOperacao,
						"CDFILIAL"			=> $cdFilial,
						"NRLANCTONF"		=> $nrLanctonf,
						"CDOPERADOR"		=> $cdOperador,
						"NRORG"				=> $nrOrg);
		
		$params = $this->adicionaCampos($params, true);
						
		$std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);
    }
    
    public function insereIntgArqXML($nrAcessoNfe, $idTipoArqXml, $dsArqXmlNfe, $nrOrg) {
    	$sql = "INSERT
				INTO INTG_ARQXMLNFE
				  (
				    NRACESSONFE,
				    IDTIPOARQXML,
				    DSARQXMLNFE_CLOB,
				    DTINCLUSAO,
					CDOPERINCLUSAO,
					NRORGINCLUSAO,
				    IDATIVO,
				    DTULTATU,
				    NRORGULTATU,
				    CDOPERULTATU,
				    NRORG
				  )
				  VALUES
				  (
				    :NRACESSONFE,
				    :IDTIPOARQXML,
				    :DSARQXMLNFE,
				    :DTINCLUSAO,
					:CDOPERINCLUSAO,
					:NRORGINCLUSAO,
					:IDATIVO,
					:DTULTATU,
					:NRORGULTATU,
					:CDOPERULTATU,
				    :NRORG
				  )";
				  
		$params = array("NRACESSONFE"		=> $nrAcessoNfe,
						"IDTIPOARQXML"		=> $idTipoArqXml,
						"DSARQXMLNFE"		=> $dsArqXmlNfe,
						"NRORG"				=> $nrOrg);
		

		$params = $this->adicionaCampos($params, true);
						
		$std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);

    }
    
    public function setArqImportado($nrAcessoNfe) {
    	$sql = "UPDATE INTG_NOTAFISCAL
		         SET IDARQXMLNFE = 'S',
                       DTULTATU    = :DTULTATU,
					   NRORGULTATU  = :NRORGULTATU,
					   CDOPERULTATU = :CDOPERULTATU
		       WHERE NRACESSONFE = :NRACESSONFE";
		       
		$params = array("NRACESSONFE"		=> $nrAcessoNfe);
		$params = $this->adicionaCampos($params, false);
		
						
		$std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);
    }
    
    public function atualizaNotaDestinada($nrAcessoNfe) {
    	$sql = "UPDATE NOTADESTINADA
		        SET NRACESSOINTG = :NRACESSONFE,
                       DTULTATU    = :DTULTATU,
					   NRORGULTATU  = :NRORGULTATU,
					   CDOPERULTATU = :CDOPERULTATU
		       WHERE NRACESSONFE = :NRACESSONFE";	
	 	
	 	$params = array("NRACESSONFE"		=> $nrAcessoNfe);
		$params = $this->adicionaCampos($params, false);
		
						
		$std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);
    }
    
    public function getParamManifesta() {
    	$sql = "SELECT IDCIENCIAEMISS, IDCONFIRMAEMISS
    			FROM PARAMMANIFESTA
    			WHERE  ((IDCIENCIAEMISS = '1') OR  (IDCONFIRMAEMISS = '1'))";
       
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute();
		return $std->fetchAll(); 
    }
	
	public function getNotaDestinada($nrAcessoNfe) {
		$sql = "SELECT NVL(IDSTATUSMANIF, '0') IDSTATUSMANIF
		        FROM NOTADESTINADA
		       WHERE NRACESSONFE = :P_NRACESSONFE";
		
		$params = array("P_NRACESSONFE"		=> $nrAcessoNfe);
		       
		$std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
		return $std->fetchAll(); 
	}
	
	public function atualizaNomeArquivo($dsNomeArquivo, $nrAcessoNfe) {
		$sql = "UPDATE INTG_NOTAFISCAL
				SET DSNMARQUXMLIMP = :P_DSNMARQUXMLIMP,
                       DTULTATU    = :DTULTATU,
					   NRORGULTATU  = :NRORGULTATU,
					   CDOPERULTATU = :CDOPERULTATU
				WHERE NRACESSONFE  = :P_NRACESSONFE";
				
		$params = array("P_DSNMARQUXMLIMP"	=> $dsNomeArquivo,
						"P_NRACESSONFE"		=> $nrAcessoNfe);
		$params = $this->adicionaCampos($params, false);
		
						
		$std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);
	}
	
	/**
     * zGravaFile
     * Grava os dados no diretorio das NFe
     *
     * @param  string $tpAmb     ambiente
     * @param  string $filename  nome do arquivo
     * @param  string $data      dados a serem salvos
     * @param  string $subFolder
     * @param  string $anomes
     * @throws Exception\RuntimeException
     */
    public function zGravaFile(
        $tpAmb = '1',
        $filename = '',
        $data = '',
        $subFolder = 'temporarias',
        $inclusao  = true,
        $cdRelac = ''
    ) {
        $tmpFile = sys_get_temp_dir().DIRECTORY_SEPARATOR.'xmlNota'.uniqid().'.xml';
        file_put_contents($tmpFile, $data);
        $file = file_get_contents($tmpFile);
        $file    = base64_encode($file);

        $file = 'data: '.mime_content_type($tmpFile).';base64,'.$file;
        
        $lastModify = filectime($tmpFile);

        $file = array(
            "name" => $filename, 
            "lastModified" => $lastModify,
            "lastModifiedDate" => '',
            "webkitRelativePath" => '',
            "type" => '',
            "size"  => filesize($tmpFile),
            "b64File" => $file);
            
        $row['XML']    = array();
        $row['XML'][0] = $file;
        
        $this->fileUploader->uploadFilesInRow($row, 'XML', $subFolder);
        unlink($tmpFile);
        
        $fileServerLink = $row['XML'][0]['path'];
        
        $subFolder = ($tpAmb == 1) ? 'producao/'.$subFolder : 'homologacao/'.$subFolder;
        
        if($inclusao === true) {
        	$this->insertIntoRelacFileServer($cdRelac, $subFolder, $fileServerLink);
        }
        else {
        	$this->updateRelacFileServer($cdRelac, $subFolder, $fileServerLink);
        }
        
        return $row['XML'][0]['path'];
        
    }
    
    private function insertIntoRelacFileServer($chNFe, $diretorio, $fileServerLink) {

        $sql = "INSERT
                INTO RELACFILESERVER
                  (
                    CDRELAC,
                    DIRETORIO,
                    FILESERVERLINK,
				    DTINCLUSAO,
					CDOPERINCLUSAO,
					NRORGINCLUSAO,
				    IDATIVO,
				    DTULTATU,
				    NRORGULTATU,
				    CDOPERULTATU,
                    NRORG
                  )
                  VALUES
                  (
                    :CDRELAC,
                    :DIRETORIO,
                    :FILESERVERLINK,
				    :DTINCLUSAO,
					:CDOPERINCLUSAO,
					:NRORGINCLUSAO,
					:IDATIVO,
					:DTULTATU,
					:NRORGULTATU,
					:CDOPERULTATU,
                    :NRORG
                  )";
        
        $params = array(
            "CDRELAC"        => $chNFe,
            "DIRETORIO"      => $diretorio,
            "FILESERVERLINK" => $fileServerLink,
            "NRORG"          => $this->environment->getNrOrgTrab()
        );

		$params = $this->adicionaCampos($params, true);
		
        $std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);
    }
    
    private function updateRelacFileServer($chNFe, $diretorio, $fileServerLink) {
    	$sql = "UPDATE RELACFILESERVER SET DIRETORIO = :DIRETORIO, FILESERVERLINK = :FILESERVERLINK,
                       DTULTATU    = :DTULTATU,
					   NRORGULTATU  = :NRORGULTATU,
					   CDOPERULTATU = :CDOPERULTATU
    			WHERE CDRELAC = :CDRELAC";
        
        $params = array(
            "CDRELAC"        => $chNFe,
            "DIRETORIO"      => $diretorio,
            "FILESERVERLINK" => $fileServerLink
        );
		$params = $this->adicionaCampos($params, false);
		

        $std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);
    }
    
    
    public function existeNotaRelac() {
        $sql = "SELECT FILESERVERLINK FROM RELACFILESERVER WHERE DIRETORIO LIKE '%/importar%'";

        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute();
		return $std->fetchAll();  
    }
    
    protected function getFileExtension($file) {
        $fileName = $file['name'];
        $lastDotIndex = (strrpos($fileName, '.') ?: -1);
        return substr($fileName, $lastDotIndex + 1);
    }
    
    public function getInscrEstad($nrInsjuriEst) {
		$sql = "SELECT CDINSCESTA
				FROM INSCRESTAD
				WHERE CDINSCESTA LIKE 'ISENT%'
				AND NRINSJURIEST = :NRINSJURIEST";
		
		$params = array("NRINSJURIEST"	=> $nrInsjuriEst);
						
		$std	= $this->entityManager->getConnection()->prepare($sql);
		$std->execute($params);
		
		$resul	= $std->fetchAll();
		
		if(isset($resul[0])) {
			return $resul[0]["CDINSCESTA"];
		}
		else return '';
	}
	
	public function getCdRelac($link) {
		$sql = "SELECT CDRELAC FROM RELACFILESERVER WHERE FILESERVERLINK = :FILESERVERLINK";
		
		$params = array("FILESERVERLINK"	=> $link);
						
		$std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
		return $std->fetchAll(); 
	}
	
	public function buscaRelacFileServer($cdRelac) {
		$sql = "SELECT CDRELAC FROM RELACFILESERVER WHERE CDRELAC = :CDRELAC";
		
		$params = array("CDRELAC"	=> $cdRelac);
						
		$std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
		return $std->fetchAll(); 
	}

	public function insereNFCP($cdfilial, $nrlanctonf, $cdempresa, $cdinscesta, $idtpijurnf, $nrinsjurnf, $cdforneced, $nrnotafisc, $dtemissao, $dtentrsaid, $vrprodutos, $vrnotafisc, $cdserieentr, $cdfilirece, $idimportada, $dtlancamennf, $nracessonfe, $idstatusnfe, $dthrprotocolnfe, $idtpambnfe, $idtipoemisnfe, $nrprotocolonfe, $dsobsstatusnfe, $cdmoddocfisc, $dsnomearquxml, $iddocfiscele, $nrorg, $cdMuniOrig = '', $cdMuniDest = '') {
		$sql = "INSERT
				INTO INTG_NOTAFISCAL
				  (
				    CDFILIAL,
				    NRLANCTONF,
				    CDEMPRESA,
				    CDINSCESTA,
				    IDTPIJURNF,
				    NRINSJURNF,
				    CDFORNECED,
				    NRNOTAFISC,
				    DTEMISSAO,
				    DTENTRSAID,
				    VRPRODUTOS,
				    VRNOTAFISC,
				    CDSERIEENTR,
				    CDFILIRECE,
				    IDIMPORTADA,
				    DTLANCAMENNF,
				    NRACESSONFE,
				    IDSTATUSNFE,
				    DTHRPROTOCOLNFE,
				    IDTPAMBNFE,
				    IDTIPOEMISNFE,
				    NRPROTOCOLONFE,
				    DSOBSSTATUSNFE,
				    CDMODDOCFISC,
				    DTIMPORTACAOXML,
				    DSNOMEARQUXML,
				    IDARQXMLNFE,
				    IDDOCFISCELE,
				    DTINCLUSAO,
					CDOPERINCLUSAO,
					NRORGINCLUSAO,
				    IDATIVO,
				    DTULTATU,
				    NRORGULTATU,
				    CDOPERULTATU,
				    CDIBGEORIG,
				    CDIBGEDEST,
				    NRORG
				  )
				  VALUES
				  (
				    :CDFILIAL,
				    :NRLANCTONF,
				    :CDEMPRESA,
				    :CDINSCESTA,
				    :IDTPIJURNF,
				    :NRINSJURNF,
				    :CDFORNECED,
				    :NRNOTAFISC,
				    :DTEMISSAO,
				    :DTENTRSAID,
				    :VRPRODUTOS,
				    :VRNOTAFISC,
				    :CDSERIEENTR,
				    :CDFILIRECE,
				    :IDIMPORTADA,
				    :DTLANCAMENNF,
				    :NRACESSONFE,
				    :IDSTATUSNFE,
				    :DTHRPROTOCOLNFE,
				    :IDTPAMBNFE,
				    :IDTIPOEMISNFE,
				    :NRPROTOCOLONFE,
				    :DSOBSSTATUSNFE,
				    :CDMODDOCFISC,
				    SYSDATE,
				    :DSNOMEARQUXML,
				    'N',
				    :IDDOCFISCELE,
				    :DTINCLUSAO,
					:CDOPERINCLUSAO,
					:NRORGINCLUSAO,
					:IDATIVO,
					:DTULTATU,
					:NRORGULTATU,
					:CDOPERULTATU,
					:CDIBGEORIG, 
					:CDIBGEDEST,
				    :NRORG
				  )";
		
		$params = array("CDFILIAL" => $cdfilial,
						"NRLANCTONF" => $nrlanctonf,
						"CDEMPRESA" => $cdempresa,
						"CDINSCESTA" => $cdinscesta,
						"IDTPIJURNF" => $idtpijurnf,
						"NRINSJURNF" => $nrinsjurnf,
						"CDFORNECED" => $cdforneced,
						"NRNOTAFISC" => $nrnotafisc,
						"DTEMISSAO" => $dtemissao,
						"DTENTRSAID" => $dtentrsaid,
						"VRPRODUTOS" => $vrprodutos,
						"VRNOTAFISC" => $vrnotafisc,
						"CDSERIEENTR" => $cdserieentr,
						"CDFILIRECE" => $cdfilirece,
						"IDIMPORTADA" => $idimportada,
						"DTLANCAMENNF" => $dtlancamennf,
						"NRACESSONFE" => $nracessonfe,
						"IDSTATUSNFE" => $idstatusnfe,
						"DTHRPROTOCOLNFE" => $dthrprotocolnfe,
						"IDTPAMBNFE" => $idtpambnfe,
						"IDTIPOEMISNFE" => $idtipoemisnfe,
						"NRPROTOCOLONFE" => $nrprotocolonfe,
						"DSOBSSTATUSNFE" => $dsobsstatusnfe,
						"CDMODDOCFISC" => $cdmoddocfisc,
						"DSNOMEARQUXML" => $dsnomearquxml,
						"IDDOCFISCELE" => $iddocfiscele,
						"CDIBGEORIG"	=> $cdMuniOrig, 
						"CDIBGEDEST"	=> $cdMuniDest,
						"NRORG" => $nrorg);
						
		$params = $this->adicionaCampos($params, true);
						
		$std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);
	}
	
	public function atualizaCfopTpOp($idEntrSaidOp, $cfop) {
		$sql = "SELECT CDTIPOOPER
				FROM CFOPXMLTPOPER
				WHERE IDENTRSAIDOP = :P_IDENTRSAIDOP
				AND CDFISCOPER     = :P_CFOP";
		
		$params = array("P_IDENTRSAIDOP"	=> $idEntrSaidOp,
						"P_CFOP"			=> $cfop);
		
		$std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
		return $std->fetchAll(); 
	}
	
	public function insereRelacCteNfe($nrAcessoNFe, $nrAcessoCte, $nrOrg) {
		$sql = "INSERT
				INTO RELACNFECTE
				  (
				    NRACESSONFE,
				    NRACESSONFECTE,
				    DTINCLUSAO,
					CDOPERINCLUSAO,
					NRORGINCLUSAO,
				    IDATIVO,
				    DTULTATU,
				    NRORGULTATU,
				    CDOPERULTATU,
				    NRORG
				  )
				  VALUES
				  (
				    :NRACESSONFE,
				    :NRACESSONFECTE,
				    :DTINCLUSAO,
					:CDOPERINCLUSAO,
					:NRORGINCLUSAO,
				    :IDATIVO,
				    :DTULTATU,
				    :NRORGULTATU,
				    :CDOPERULTATU,
				    :NRORG
				  )";
		
		$params = array("NRACESSONFE"		=> $nrAcessoNFe,
						"NRACESSONFECTE"	=> $nrAcessoCte,
						"NRORG"				=> $nrOrg);
						
		$params = $this->adicionaCampos($params, true);
		
		$std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);
	}
	
	
	protected function adicionaCampos($params, $is_new) {
        $nrorg = $this->environment->getNrorgTrab();
		$operador = $this->environment->getCdOperador();
		$currentTime = $this->environment->getCurrentTime()->format("d/m/Y");
		
		
		if($is_new == true) {
			$params['DTINCLUSAO'] = $currentTime;
			$params['CDOPERINCLUSAO'] = $operador;
			$params['NRORGINCLUSAO'] = $nrorg;
			$params['IDATIVO'] = 'S';
			$params['NRORG'] = $nrorg;
		}
		
		$params['DTULTATU'] = $currentTime;
		$params['NRORGULTATU'] = $nrorg;
		$params['CDOPERULTATU'] = $operador;
		
		return $params;
    }
    
   public function insereXml($params) { 
   	
   		
        $sql = "INSERT
                INTO HISTXMLNFE
                (
                    NRACESSONFE, 
                    NRSEQHISTOR, 
                    DTHISTORICO, 
                    IDTIPOOPER,
                    IDSTATUS,
                    NRPROTOCOLONFE, 
                    DSOPERACAO,
                    CDFILIAL,
                    NRLANCTONF,
                    CDOPERADOR
                )
                VALUES 
                (
                    :NRACESSONFE,
                    :NRSEQHISTOR,                     
                    :DTHISTORICO, 
                    :IDTIPOOPER,
                    :IDSTATUS, 
                    :NRPROTOCOLONFE, 
                    :DSOPERACAO, 
                    :CDFILIAL,
                    :NRLANCTONF, 
                    :CDOPERADOR
                )";
         

        $query =  $this->entityManager->getConnection()->prepare($sql);
        return $query->execute($params);
        
      
    }
    
    
     public function atualizaStatusXml($nrAcessoNfe, $idStatusNfe){
        $sql = "UPDATE 
                INTG_NOTAFISCAL
                SET 
                IDSTATUSNFE = :P_IDSTATUSNFE
                WHERE 
                NRACESSONFE = :P_NRACESSONFE";
                
                
        $params = array(
            "P_IDSTATUSNFE" => $idStatusNfe,
            "P_NRACESSONFE" => $nrAcessoNfe
            
        );
        


        $query =  $this->entityManager->getConnection()->prepare($sql);
        return $query->execute($params);
       
    } 
    
    
     public function getDefaultFilterImportacao($cdfilial) {
        $sql = "SELECT CDFILIAL, CDINSCESTA, NMFILIAL FROM FILIAL WHERE CDFILIAL = :P_CDFILIAL";
        
        $params = array(
            "P_CDFILIAL"        => $cdfilial
        );

        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
		return $std->fetch();  
    }
    
    public function getItensPendentesParametrizacao($entityManager) {
    	$sql = "SELECT F.CDFORNECED,
				  IT.CDPRODUTO,
				  IT.NMPRODUTO,
				  IT.CDPRODUTOXML,
				  F.NRINSJURFORN,
				  F.NMRAZSOCFORN,
				  NVL(I.DSEMAILDESTXML,P.DSEMAILITPEN) AS DSEMAILITPEN          
				FROM
				  (SELECT N.CDFORNECED,
				    IT.CDPRODUTO,
				    IT.NMPRODUTO,
				    P.CDPRODUTOXML
				  FROM INTG_NOTAFISCAL N,
				    INTG_ITEMPRODUTO IT,
				    PRODFORNXML P
				  WHERE IT.CDPRODUTO    = P.CDPRODUTOXML(+)
				  AND N.NRACESSONFE     = IT.NRACESSONFE
				  AND NVL(N.IDIMPORTADA, 'N')     <> 'S'
				  AND N.IDENVEMAILITPEN = 'N'
				  ) IT,
				  FORNECEDOR F,
				  PARAMFORNE P
        LEFT OUTER JOIN PARAMINTEGRA I ON P.NRORG = I.NRORG    
				WHERE F.CDFORNECED   = IT.CDFORNECED
				AND F.CDFORNECED     = P.CDFORNECED
				AND IT.CDPRODUTOXML IS NULL
				AND DSEMAILITPEN IS NOT NULL";
					
        if($entityManager) {
        	$std = $entityManager->getConnection()->prepare($sql);
        }
		else {
	        $std = $this->entityManager->getConnection()->prepare($sql);
		}

        $std->execute();
		return $std->fetchAll();  			
		
    }
    
    public function updateEmailItemPendente($cdforneced, $entityManager) {
    	$sql = "UPDATE INTG_NOTAFISCAL
				SET IDENVEMAILITPEN = 'S'
				WHERE CDFORNECED    = :P_CDFORNECED
				AND IDENVEMAILITPEN = 'N'";
					
		$params = array(
            "P_CDFORNECED"		 => $cdforneced
        );
    
        if($entityManager) {
        	$std = $entityManager->getConnection()->prepare($sql);
        }
		else {
	        $std = $this->entityManager->getConnection()->prepare($sql);
		}

        $std->execute($params);
    }
    
    
    public function getDadosSmtpItensPendentes($entityManager) {
    	$sql = "SELECT NVL (B.DSLOGINSMTPGENTR,E.DSLOGINSMTP) AS DSLOGINSMTP, NVL(B.DSSMTPEMAILFGENTR, E.DSSMTPEMAILF)AS DSSMTPEMAILF,
				NVL(B.CDSENHEMAILFGENTR,E.CDSENHEMAILF) AS CDSENHEMAILF , NVL (B.IDUTTLSEMAILGENTR, E.IDUTTLSEMAIL) AS IDUTTLSEMAIL,
				NVL (B.IDUTSSLEMAILGENTR,E.IDUTSSLEMAIL)AS IDUTSSLEMAIL, P.DSEMAILREMETXML AS REMETENTE
                  FROM PARAMINTEGRA P, PARGERALDFE B, ENDEFILI E
                  JOIN FILIAL F ON (E.CDFILIAL = F.CDFILIAL)
                               AND (E.NRORG = F.NRORG)
                 WHERE IDTPENDEFILI = 'P'
                   AND F.CDFILIAL = (SELECT MAX(CDFILIAL)
                                       FROM FILIAL
                                      WHERE NRORG = :P_NRORG)
                  AND P.NRORG = E.NRORG
                  AND B.NRORG = E.NRORG";
		
        $params = ["P_NRORG" => $this->environment->getNrOrgTrab()];
        
        if($entityManager) $std = $entityManager->getConnection()->prepare($sql);
		else			   $std = $this->entityManager->getConnection()->prepare($sql);
		
        $std->execute($params);
		return $std->fetch();
    }
    
    
    public function removeAcentos($str) {
	    $str = preg_replace('/[áàãâä]/ui', 'a', $str);
	    $str = preg_replace('/[éèêë]/ui', 'e', $str);
	    $str = preg_replace('/[íìîï]/ui', 'i', $str);
	    $str = preg_replace('/[óòõôö]/ui', 'o', $str);
	    $str = preg_replace('/[úùûü]/ui', 'u', $str);
	    $str = preg_replace('/[ç]/ui', 'c', $str);
	    return $str;
    }
    
     public function getImpostosMFSe() {
        $sql = "SELECT CDIMPOSTO,
                  SGIMPOSTONFE
                FROM IMPOSTO I,
                  IMPOSTONFE IM
                WHERE I.CDIMPOSTOXML = IM.CDIMPOSTONFE
                AND IM.SGIMPOSTONFE IN ('PIS','CSLL','INSS -','PIS','COFINS', 'ISS', 'IR', 'CONFIS', 'COFINS ST')";
                
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute();
        return $std->fetchAll();          
    }

    
    public function getImpostosFacturacion() {
    	$sql = "SELECT CDIMPOSTO,
                  SGIMPOSTONFE,
                  IDIMPORTAIMPXML
                FROM IMPOSTO I,
                  IMPOSTONFE IM
                WHERE I.CDIMPOSTOXML = IM.CDIMPOSTONFE
                AND IM.SGIMPOSTONFE IN ('IVA','IMPOCONSUM')";
                
    	$std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute();
        return $std->fetchAll();   
    }
    
    public function getModeloDocumento($modDocFisc) {
    	$sql = "SELECT CDMODDOCFISC
                FROM MODDOCFISC M
                WHERE M.CDMODDOCFISC = :P_CDMODDOCFISC";
                
		$params = array(
            "P_CDMODDOCFISC"		 => $modDocFisc
        );        
              
    	$std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();   
    }
    
    public function deletaRelacFileServer($cdRelac, $diretorio) {
    	$sql = "DELETE FROM RELACFILESERVER WHERE CDRELAC = :P_CDRELAC AND DIRETORIO LIKE '%$diretorio%'";
    	
		$params = array(
            "P_CDRELAC"		 => $cdRelac
        );        
              
    	$std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
    }
    
    public function updateDesvinculaAfNotafiscal ($nrAcessoNfe, $numeroAf){
    	$sql = "UPDATE INTG_ITEMPRODUTO
				SET NRAUTOFORN = :P_NUMEROAF
				WHERE NRACESSONFE = :P_NRACESSONFE";
		$params = array (
			"P_NUMEROAF" => $numeroAf,
			"P_NRACESSONFE" => $nrAcessoNfe
		);
    	$std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);
    }
    
    public function desvinculaAfNotafiscal($nrAcessoNfe) {
    	$sql = "DELETE
			FROM INTG_ITEMAF
			WHERE NRACESSONFE = :P_NRACESSONFE";
    	
    	$params = array ( 
			"P_NRACESSONFE" => $nrAcessoNfe
		);
		
    	$std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);
    }
    
    public function updateDesvinculaAfProduto($nrAcessoNfe, $numeroAf, $nrSeqItProd) {
    	$sql = "UPDATE INTG_ITEMPRODUTO
				SET NRAUTOFORN = :P_NUMEROAF
				WHERE NRACESSONFE = :P_NRACESSONFE
				AND NRSEQITPROD = :P_NRSEQITPROD";
		$params = array (
			"P_NRACESSONFE" => $nrAcessoNfe,
			"P_NUMEROAF" => $numeroAf,
			"P_NRSEQITPROD" => $nrSeqItProd
		);
		
    	$std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);
    }
    
    public function desvinculaAfProduto($nrAcessoNfe, $nrSeqItProd) {
    	$sql = "DELETE
				FROM INTG_ITEMAF
				WHERE NRACESSONFE = :P_NRACESSONFE
				AND NRSEQITPROD = :P_NRSEQITPROD";
		$params = array (
			"P_NRACESSONFE" => $nrAcessoNfe,
			"P_NRSEQITPROD" => $nrSeqItProd

		);
    	$std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);
    }
    
    public function limpaLoginXML(){
    	$sql = "DELETE
				FROM LOGINCONSXML";

    	$std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute();
    }
    public function getDiretorioLogo($nrAcessoNfe) {
        $sql = "SELECT DSDIRLOGOMARCA  
        		FROM EMPRESA 
        		WHERE CDEMPRESA = 
        			( SELECT CDEMPRESA FROM NOTAFISCAL  WHERE NRACESSONFE = :P_NRACESSONFE)";
        $params   = array (
			"P_NRACESSONFE" => $nrAcessoNfe
		);  
           
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();  
    }
    
    public function getLogo($nrAcessoNfe) {
        $sql = " SELECT DSARQLOGOEMPCLOB  
        		 FROM EMPRESA 
				 WHERE CDEMPRESA = ( SELECT CDEMPRESA FROM NOTAFISCAL  WHERE NRACESSONFE = :P_NRACESSONFE) ";
        $params   = array (
			"P_NRACESSONFE" => $nrAcessoNfe
		);  
           
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();  
    }
    
    public function setAgendamentoImportacao($nrorg, $useVpd, $newEntityManager, $newFileUploader) {
        if($useVpd)    $this->entityManager = $newEntityManager;
        if($nrorg > 1) $this->fileUploader  = $newFileUploader;
        
        $this->environment->setNrOrg($nrorg);
        $this->environment->setNrOrgTrab($nrorg);
        $this->environment->setCurrentUserId('AUTOMATICO');
    }
    
    public function updateDSDIRIMPARQXML_default(){
    	$sql = "update PARAMINTEGRA set DSDIRIMPARQXML = '/tmp/'";
           
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute();
    }

    public function getCdMunicipio($cdMunicIbge) {
	         $sql = "SELECT CDMUNICIPIO
			               FROM MUNICIPIO
				                    WHERE CDMUNICIBGE = :CDMUNICIBGE";
            
        $params = array("CDMUNICIBGE"   => $cdMunicIbge);
        
        $std = $this->entityManager->getConnection()->prepare($sql);
	        $std->execute($params);
	        return $std->fetchAll();
		        
    }
    
    public function insereMunicipio($cdPais,$sgEstado,$cdMunicipio,$mnMunicipio,$cdMunicipioIbge,$nrorg) {
        $sql = "INSERT INTO MUNICIPIO
           (CDPAIS,
            SGESTADO,
            CDMUNICIPIO,
            NMMUNICIPIO,
            CDMUNICIBGE,
            NRORG)
        VALUES
           ((SELECT CDPAIS FROM PAIS WHERE CDPAISBACEN = :CDPAIS),
            :SGESTADO,
            :CDMUNICIPIO,
            :NMMUNICIPIO,
            :CDMUNICIBGE,
            :NRORG)";
                    
        $params = array("CDPAIS" => $cdPais,
                        "SGESTADO" => $sgEstado,
                        "CDMUNICIPIO" => $cdMunicipio,
                        "NMMUNICIPIO" => $mnMunicipio,
                        "CDMUNICIBGE" => $cdMunicipioIbge,
                        "NRORG" => $nrorg);
                        
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);    
	        
	}
}