<?php

namespace Teknisa\DF\Modules\Entrada\Factories;

/* Bibliotecas */
use Doctrine\ORM\EntityManager;
use Teknisa\Libs\Util\DateUtil;
use Teknisa\Libs\Util\NewCode;
use Teknisa\Model\Fiscal\Entities\Arqxmlnfe;
use Teknisa\Model\Fiscal\Entities\Notadestinada;
use Zeedhi\Framework\DependencyInjection\InstanceManager;
use Zeedhi\Framework\Remote\FileUploader\Server as fileUploader;

class NumeracaoTransmissaoNfeFactory {
    
    protected $entityManager;
    protected $fileUploader;
    protected $environment;

    public function __construct(EntityManager $entityManager, $environment, $novoCodigo, $fileUploader) {
        $this->entityManager = $entityManager;
        $this->environment   = $environment;
        $this->novoCodigo    = $novoCodigo;
        $this->fileUploader  = $fileUploader;
        set_time_limit(0);
    }
    
    public function getSerieNfe($cdempresa, $cdinscesta, $nrinsjuriest) {
        $sql = "SELECT CDEMPRESA, CDINSCESTA, CDINSCMUNI, CDSERIE, DSSERIE, CDSERIENFE, '1' AS IDTIPOEMISNFE, '$nrinsjuriest' as NRINSJURIEST
                  FROM SERIENF
                 WHERE CDEMPRESA = :P_CDEMPRESA
                   AND CDINSCESTA = :P_CDINSCESTA
                   AND CDSERIENFE IS NOT NULL
                 UNION ALL
                SELECT CDEMPRESA, CDINSCESTA, CDINSCMUNI, CDSERIE, DSSERIE, CDSERIENFESCAN AS CDSERIENFE, '3' AS IDTIPOEMISNFE, '$nrinsjuriest' as NRINSJURIEST
                  FROM SERIENF
                 WHERE CDEMPRESA = :P_CDEMPRESA
                   AND CDINSCESTA = :P_CDINSCESTA
                   AND CDSERIENFESCAN IS NOT NULL";
        
        $params = array(
            "P_CDEMPRESA"        => $cdempresa,
            "P_CDINSCESTA"        => $cdinscesta
        );

        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
		return $std->fetchAll();  
    }
    
    public function getNovoCodigo($cdempresa, $nrinsjuriest, $cdserienfe, $idtpambientenfe) {
        $sql = "SELECT CDCONTADOR, NRSEQUENCIAL, $idtpambientenfe AS TPAMBIENTE, $cdserienfe AS SERIENFE, $nrinsjuriest as NRINSJURIEST
                  FROM NOVOCODIGO
                 WHERE CDCONTADOR = 'NOTAFISCALELE' || :P_CDEMPRESA || :P_NRINSJURIEST || :P_CDSERIENFE || :P_IDTPAMBIENTENFE";
                     
        $params = array(
            "P_NRINSJURIEST"     => $nrinsjuriest,
            "P_CDSERIENFE"       => $cdserienfe,
            "P_CDEMPRESA"        => $cdempresa,
            "P_IDTPAMBIENTENFE"  => $idtpambientenfe
        );

        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
		return $std->fetchAll();
    }
    
    
    public function verificaNumInutilNFEle($cdempresa, $nrinsjuriest, $cdserienfe, $nrinutilnfele, $idtpambientenfe) {
        $sql = "SELECT CDEMPRESA,
                       NRINSJURIESTNFE,
                       CDINSCESTA,
                       CDINSCMUNI,
                       CDSERIE, 
                       NRINUTILNFELE,
                       IDTPAMBNFENUM,
                       DTINUTNFE,
                       NRPROTOCINUTNFE,
                       IDTPEMISINUTIL,
                       DSJUSNUMINUTILNFE
                  FROM NUMINUTILNFELE
                 WHERE CDEMPRESA =  :P_CDEMPRESA
                   AND NRINSJURIESTNFE = :P_NRINSJURIESTNFE
                   AND CDSERIE = :P_CDSERIE
                   AND NRINUTILNFELE = :P_NRINUTILNFELE
                   AND IDTPAMBNFENUM = :P_IDTPAMBNFENUM";
                     
        $params = array(
            "P_CDEMPRESA"        => $cdempresa,
            "P_NRINSJURIESTNFE"  => $nrinsjuriest,
            "P_CDSERIE"       => $cdserienfe,
            "P_NRINUTILNFELE"   => $nrinutilnfele,
            "P_IDTPAMBNFENUM" => $idtpambientenfe
        );

        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
		return $std->fetchAll();
    }
    
    public function insereNovoCodigo($cdcontador, $nrsequencial){
        $sql = "INSERT INTO NOVOCODIGO
                   (CDCONTADOR, NRSEQUENCIAL)
                VALUES
                   (:P_CDCONTADOR, :P_NRSEQUENCIAL)";
                    
                
        $params = array(
            "P_CDCONTADOR" => $cdcontador,
            "P_NRSEQUENCIAL" => $nrsequencial
        );

        $std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);
    }
    
    public function alteraNovoCodigo($cdcontador, $nrsequencial) {
        $sql = "UPDATE NOVOCODIGO
               SET NRSEQUENCIAL = :P_NRSEQUENCIAL
             WHERE CDCONTADOR   = :P_CDCONTADOR ";
                
        $params = array(
            "P_CDCONTADOR" => $cdcontador,
            "P_NRSEQUENCIAL" => $nrsequencial
        );
            
        $std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);    
    }
    
    
    public function insereNumInutilNFEle($cdempresa, $nrinsjuriestnfe, $cdserie, $nrinutilnfele, $idtpabnfenum, $cdinscesta, $cdinscmuni, $nrprotocinutnfe, $idtpemisinutil, $dsjusnuminutilnfe) {
        $sql = "INSERT INTO NUMINUTILNFELE
                       (CDEMPRESA, 
                        NRINSJURIESTNFE, 
                        CDSERIE, 
                        NRINUTILNFELE,
                        IDTPAMBNFENUM, 
                        DTINUTNFE, 
                        CDINSCESTA, 
                        CDINSCMUNI,
                        NRPROTOCINUTNFE,
                        IDTPEMISINUTIL, 
                        DSJUSNUMINUTILNFE)
                    VALUES
                       (:CDEMPRESA, 
                        :NRINSJURIESTNFE, 
                        :CDSERIE, 
                        :NRINUTILNFELE,
                        :IDTPAMBNFENUM, 
                        SYSDATE,
                        :CDINSCESTA,
                        :CDINSCMUNI,
                        :NRPROTOCINUTNFE,
                        :IDTPEMISINUTIL,
                        :DSJUSNUMINUTILNFE)";
                
        $params = array(
            "CDEMPRESA"         => $cdempresa,
            "NRINSJURIESTNFE"   => $nrinsjuriestnfe,
            "CDSERIE"           => $cdserie,
            "NRINUTILNFELE"     => $nrinutilnfele,
            "IDTPAMBNFENUM"     => $idtpabnfenum,
            "CDINSCESTA"        => $cdinscesta,
            "CDINSCMUNI"        => $cdinscmuni,
            "NRPROTOCINUTNFE"   => $nrprotocinutnfe,
            "IDTPEMISINUTIL"    => $idtpemisinutil,
            "DSJUSNUMINUTILNFE" => $dsjusnuminutilnfe
        );
        
        $std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);
    }
    
    public function insereLogOpera($nmoperador, $tipo, $cdpesqitem, $descricao, $cdoperador) {
        $sql = " INSERT INTO LOGOPERA
                       (NMTABELA,   DTOPERACAO, NMRESPOPER,
                        IDTIPOOPER, CDPESQITEM, DSOPERACAO, CDORESPOPER)
                    VALUES
                       ('NOVOCODIGO',   SYSDATE,      :P_NMOPERADOR,
                        :P_TIPO,       :P_CDPESQITEM, :P_DESCRICAO, :P_CDOPERADOR)";
                
        $params = array(
            "P_NMOPERADOR" => $nmoperador,
            "P_TIPO"       => $tipo,
            "P_CDPESQITEM" => $cdpesqitem,
            "P_DESCRICAO"  => $descricao,
            "P_CDOPERADOR" => $cdoperador
        );
        
        $std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);
    }
  
}